/* Generated by Nim Compiler v1.6.6 */
#define NIM_INTBITS 32
#define NIM_EmulateOverflowChecks

#include "nimbase.h"
#include <string.h>
#include <stdio.h>
#undef LANGUAGE_C
#undef MIPSEB
#undef MIPSEL
#undef PPC
#undef R3000
#undef R4000
#undef i386
#undef linux
#undef mips
#undef near
#undef far
#undef powerpc
#undef unix
  #  define nimfr_(proc, file) \
      TFrame FR_; \
      FR_.procname = proc; FR_.filename = file; FR_.line = 0; FR_.len = 0; nimFrame(&FR_);

  #  define nimfrs_(proc, file, slots, length) \
      struct {TFrame* prev;NCSTRING procname;NI line;NCSTRING filename; NI len; VarSlot s[slots];} FR_; \
      FR_.procname = proc; FR_.filename = file; FR_.line = 0; FR_.len = length; nimFrame((TFrame*)&FR_);

  #  define nimln_(n, file) \
      FR_.line = n; FR_.filename = file;
  typedef struct tyObject_PyLibcolonObjectType___bTw708kK89b8Vj9cmSu9a4zig tyObject_PyLibcolonObjectType___bTw708kK89b8Vj9cmSu9a4zig;
typedef struct tySequence__M73GJ9bOx1XdoIRnhIyhqTQ tySequence__M73GJ9bOx1XdoIRnhIyhqTQ;
typedef struct TGenericSeq TGenericSeq;
typedef struct tyObject_ExportedModule__fxDBwb9c9c8NsdRe9bmg8Q9a2A tyObject_ExportedModule__fxDBwb9c9c8NsdRe9bmg8Q9a2A;
typedef struct NimStringDesc NimStringDesc;
typedef struct TNimType TNimType;
typedef struct TNimNode TNimNode;
typedef struct tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g;
typedef struct tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w;
typedef struct tyObject_GcHeap__1TRH1TZMaVZTnLNcIHuNFQ tyObject_GcHeap__1TRH1TZMaVZTnLNcIHuNFQ;
typedef struct tyObject_GcStack__7fytPA5bBsob6See21YMRA tyObject_GcStack__7fytPA5bBsob6See21YMRA;
typedef struct tyObject_MemRegion__x81NhDv59b8ercDZ9bi85jyg tyObject_MemRegion__x81NhDv59b8ercDZ9bi85jyg;
typedef struct tyObject_SmallChunk__tXn60W2f8h3jgAYdEmy5NQ tyObject_SmallChunk__tXn60W2f8h3jgAYdEmy5NQ;
typedef struct tyObject_BigChunk__Rv9c70Uhp2TytkX7eH78qEg tyObject_BigChunk__Rv9c70Uhp2TytkX7eH78qEg;
typedef struct tyObject_LLChunk__XsENErzHIZV9bhvyJx56wGw tyObject_LLChunk__XsENErzHIZV9bhvyJx56wGw;
typedef struct tyObject_IntSet__EZObFrE3NC9bIb3YMkY9crZA tyObject_IntSet__EZObFrE3NC9bIb3YMkY9crZA;
typedef struct tyObject_Trunk__W0r8S0Y3UGke6T9bIUWnnuw tyObject_Trunk__W0r8S0Y3UGke6T9bIUWnnuw;
typedef struct tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw;
typedef struct tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg;
typedef struct tyTuple__ujsjpB2O9cjj3uDHsXbnSzg tyTuple__ujsjpB2O9cjj3uDHsXbnSzg;
typedef struct tyObject_GcStat__0RwLoVBHZPfUAcLczmfQAg tyObject_GcStat__0RwLoVBHZPfUAcLczmfQAg;
typedef struct tyObject_CellSet__jG87P0AI9aZtss9ccTYBIISQ tyObject_CellSet__jG87P0AI9aZtss9ccTYBIISQ;
typedef struct tyObject_PageDesc__fublkgIY4LG3mT51LU2WHg tyObject_PageDesc__fublkgIY4LG3mT51LU2WHg;
typedef struct tyObject_PyTypeObject3Obj__cRsC9bGvH9bX6A9aVx8UB6I5g tyObject_PyTypeObject3Obj__cRsC9bGvH9bX6A9aVx8UB6I5g;
typedef struct tyObject_RawPyBuffer__0qyRdSZKtLACJ1u4qMMP2w tyObject_RawPyBuffer__0qyRdSZKtLACJ1u4qMMP2w;
typedef struct tyObject_Complex__zWadV1X9aMO7qS9bsQFB0JFA tyObject_Complex__zWadV1X9aMO7qS9bsQFB0JFA;
typedef struct tyObject_PyMethodDef__9aWi1PsmvCuTKIYDHHnhfcw tyObject_PyMethodDef__9aWi1PsmvCuTKIYDHHnhfcw;
typedef struct tyTuple__47w2DboNEPf69aPgubZdd7Q tyTuple__47w2DboNEPf69aPgubZdd7Q;
typedef struct tyObject_ValueError__yoNlBGx0D2tRizIdhQuENw tyObject_ValueError__yoNlBGx0D2tRizIdhQuENw;
typedef struct tyObject_CatchableError__qrLSDoe2oBoAqNtJ9badtnA tyObject_CatchableError__qrLSDoe2oBoAqNtJ9badtnA;
typedef struct Exception Exception;
typedef struct RootObj RootObj;
typedef struct tySequence__uB9b75OUPRENsBAu4AnoePA tySequence__uB9b75OUPRENsBAu4AnoePA;
typedef struct tyObject_PyObjectVarHeadObj__5fAkl5kIcYJNl6VvYzZdMw tyObject_PyObjectVarHeadObj__5fAkl5kIcYJNl6VvYzZdMw;
typedef struct tyObject_PyObjectObj__aD5pkFWInXrZXinZ42cDEg tyObject_PyObjectObj__aD5pkFWInXrZXinZ42cDEg;
typedef struct tyObject_PyMemberDef__WC29aEeHi2Pdy9c4AkllcBTg tyObject_PyMemberDef__WC29aEeHi2Pdy9c4AkllcBTg;
typedef struct tyObject_StackTraceEntry__oLyohQ7O2XOvGnflOss8EA tyObject_StackTraceEntry__oLyohQ7O2XOvGnflOss8EA;
struct TGenericSeq {
NI len;
NI reserved;
};
struct NimStringDesc {
  TGenericSeq Sup;
NIM_CHAR data[SEQ_DECL_SIZE];
};
struct tyObject_ExportedModule__fxDBwb9c9c8NsdRe9bmg8Q9a2A {
NimStringDesc* name;
void* initAddr2;
void* initAddr3;
};
typedef NU8 tyEnum_TNimKind__jIBKr1ejBgsfM33Kxw4j7A;
typedef NU8 tySet_tyEnum_TNimTypeFlag__v8QUszD1sWlSIWZz7mC4bQ;
typedef N_NIMCALL_PTR(void, tyProc__ojoeKfW4VYIm36I9cpDTQIg) (void* p, NI op);
typedef N_NIMCALL_PTR(void*, tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ) (void* p);
struct TNimType {
NI size;
NI align;
tyEnum_TNimKind__jIBKr1ejBgsfM33Kxw4j7A kind;
tySet_tyEnum_TNimTypeFlag__v8QUszD1sWlSIWZz7mC4bQ flags;
TNimType* base;
TNimNode* node;
void* finalizer;
tyProc__ojoeKfW4VYIm36I9cpDTQIg marker;
tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ deepcopy;
};
typedef NU8 tyEnum_TNimNodeKind__unfNsxrcATrufDZmpBq4HQ;
struct TNimNode {
tyEnum_TNimNodeKind__unfNsxrcATrufDZmpBq4HQ kind;
NI offset;
TNimType* typ;
NCSTRING name;
NI len;
TNimNode** sons;
};
typedef N_NIMCALL_PTR(void, tyProc__T4eqaYlFJYZUv9aG9b1TV0bQ) (void);
struct tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g {
NI refcount;
TNimType* typ;
};
struct tyObject_GcStack__7fytPA5bBsob6See21YMRA {
void* bottom;
};
struct tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w {
NI len;
NI cap;
tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g** d;
};
typedef tyObject_SmallChunk__tXn60W2f8h3jgAYdEmy5NQ* tyArray__SPr7N6UKfuF549bNPiUvSRw[256];
typedef NU32 tyArray__BHbOSqU1t9b3Gt7K2c6fQig[24];
typedef tyObject_BigChunk__Rv9c70Uhp2TytkX7eH78qEg* tyArray__N1u1nqOgmuJN9cSZrnMHgOQ[32];
typedef tyArray__N1u1nqOgmuJN9cSZrnMHgOQ tyArray__B6durA4ZCi1xjJvRtyYxMg[24];
typedef tyObject_Trunk__W0r8S0Y3UGke6T9bIUWnnuw* tyArray__lh2A89ahMmYg9bCmpVaplLbA[256];
struct tyObject_IntSet__EZObFrE3NC9bIb3YMkY9crZA {
tyArray__lh2A89ahMmYg9bCmpVaplLbA data;
};
typedef tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* tyArray__0aOLqZchNi8nWtMTi8ND8w[2];
struct tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw {
tyArray__0aOLqZchNi8nWtMTi8ND8w link;
NI key;
NI upperBound;
NI level;
};
struct tyTuple__ujsjpB2O9cjj3uDHsXbnSzg {
tyObject_BigChunk__Rv9c70Uhp2TytkX7eH78qEg* Field0;
NI Field1;
};
typedef tyTuple__ujsjpB2O9cjj3uDHsXbnSzg tyArray__LzOv2eCDGiceMKQstCLmhw[30];
struct tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg {
NI len;
tyArray__LzOv2eCDGiceMKQstCLmhw chunks;
tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg* next;
};
struct tyObject_MemRegion__x81NhDv59b8ercDZ9bi85jyg {
NI minLargeObj;
NI maxLargeObj;
tyArray__SPr7N6UKfuF549bNPiUvSRw freeSmallChunks;
NU32 flBitmap;
tyArray__BHbOSqU1t9b3Gt7K2c6fQig slBitmap;
tyArray__B6durA4ZCi1xjJvRtyYxMg matrix;
tyObject_LLChunk__XsENErzHIZV9bhvyJx56wGw* llmem;
NI currMem;
NI maxMem;
NI freeMem;
NI occ;
NI lastSize;
tyObject_IntSet__EZObFrE3NC9bIb3YMkY9crZA chunkStarts;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* root;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* deleted;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* last;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* freeAvlNodes;
NIM_BOOL locked;
NIM_BOOL blockChunkSizeIncrease;
NI nextChunkSize;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw bottomData;
tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg heapLinks;
};
struct tyObject_GcStat__0RwLoVBHZPfUAcLczmfQAg {
NI stackScans;
NI cycleCollections;
NI maxThreshold;
NI maxStackSize;
NI maxStackCells;
NI cycleTableSize;
NI64 maxPause;
};
struct tyObject_CellSet__jG87P0AI9aZtss9ccTYBIISQ {
NI counter;
NI max;
tyObject_PageDesc__fublkgIY4LG3mT51LU2WHg* head;
tyObject_PageDesc__fublkgIY4LG3mT51LU2WHg** data;
};
struct tyObject_GcHeap__1TRH1TZMaVZTnLNcIHuNFQ {
tyObject_GcStack__7fytPA5bBsob6See21YMRA stack;
NI cycleThreshold;
NI zctThreshold;
tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w zct;
tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w decStack;
tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w tempStack;
NI recGcLock;
tyObject_MemRegion__x81NhDv59b8ercDZ9bi85jyg region;
tyObject_GcStat__0RwLoVBHZPfUAcLczmfQAg stat;
tyObject_CellSet__jG87P0AI9aZtss9ccTYBIISQ marked;
tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w additionalRoots;
NI gcThreadId;
};
typedef N_CDECL_PTR(void*, tyProc__SsjMo29bx9bP5kwe2xgM3Scg) (NCSTRING f, ...);
typedef N_CDECL_PTR(void*, tyProc__4wJmT85lsn175X0dPNQv7w) (NI sz);
typedef N_CDECL_PTR(NI, tyProc__YRQqZC12s3573tRGP8MV3g) (void* f);
typedef N_CDECL_PTR(void*, tyProc__oPIasAghCTvCKmvkMeB1xQ) (void* f, NI i);
typedef N_CDECL_PTR(int, tyProc__6slETyyIDJuDOSqkO0hUXA) (void* f, NI i, void* v);
typedef N_CDECL_PTR(int, tyProc__tgpXIILGoVcO9bvYnz9azTVQ) (tyObject_PyTypeObject3Obj__cRsC9bGvH9bX6A9aVx8UB6I5g* f);
typedef N_CDECL_PTR(void*, tyProc__eYT4U6bGFqFBUxk9b15mfOA) (tyObject_PyTypeObject3Obj__cRsC9bGvH9bX6A9aVx8UB6I5g* f, void* a, void* b);
typedef N_CDECL_PTR(int, tyProc__T08W9bgbY4bOv2q64h6irpw) (void* m, NCSTRING n, void* o);
typedef N_CDECL_PTR(void*, tyProc__uQWqJp3WAx8fOY1h9aCwjIg) (void* callable_object, void* args, void* kw);
typedef N_CDECL_PTR(int, tyProc__fbYpjfe38x3ujjAmVRbI1Q) (void* o);
typedef N_CDECL_PTR(void*, tyProc__YezmFzxOOyM9cb11Eoq1Elg) (void* o, NCSTRING name);
typedef N_CDECL_PTR(void*, tyProc__jvPpjMAkI9bwM1B9apOphnlA) (void* o);
typedef N_CDECL_PTR(void*, tyProc__VQ1ysQk017myXMGb79cPTVw) (void* o, void* k);
typedef N_CDECL_PTR(int, tyProc__7LMjBc4zOHVIsNdulNv7QQ) (void* o, void* k, void* v);
typedef N_CDECL_PTR(int, tyProc__eoRP3F9aLT3mtHj6OkcMSyQ) (void* a, void* b, int op);
typedef N_CDECL_PTR(int, tyProc__8hR9arLDkUs9ag3Pt9bWtjfsg) (void* o, tyObject_RawPyBuffer__0qyRdSZKtLACJ1u4qMMP2w* b, int flags);
typedef N_CDECL_PTR(void, tyProc__vFvpnKOere9bRFN9czzMRlTA) (tyObject_RawPyBuffer__0qyRdSZKtLACJ1u4qMMP2w* b);
typedef N_CDECL_PTR(void*, tyProc__BZ6N5NNdHcK05FTDxQbEWw) (NCSTRING name, void* base, void* dict);
typedef N_CDECL_PTR(NI64, tyProc__mIlNZ9aGaphVJCyIIofK8mg) (void* l);
typedef N_CDECL_PTR(NU64, tyProc__9b5I9aMvpc2qfvARBMMx9blAg) (void* l);
typedef N_CDECL_PTR(double, tyProc__2su9b9chqHYibM7sMkbSaSkA) (void* l);
typedef N_CDECL_PTR(void*, tyProc__RKlUmjvtmKGnc01PbvZaRQ) (long v);
typedef N_CDECL_PTR(int, tyProc__i2exZ7Vtp648U9crOFcq9beQ) (tyObject_PyTypeObject3Obj__cRsC9bGvH9bX6A9aVx8UB6I5g* t1, tyObject_PyTypeObject3Obj__cRsC9bGvH9bX6A9aVx8UB6I5g* t2);
struct tyObject_Complex__zWadV1X9aMO7qS9bsQFB0JFA {
NF re;
NF im;
};
typedef N_CDECL_PTR(tyObject_Complex__zWadV1X9aMO7qS9bsQFB0JFA, tyProc__N1A5ZvDSgO9c9aRXmVqfn9bAw) (void* op);
typedef N_CDECL_PTR(void*, tyProc__6esIxH9aNBn9aNzK4x86GkYw) (NIM_CHAR* s, NI len);
typedef N_CDECL_PTR(int, tyProc__3FKLKFzOaK7FD6dRLWM6Jw) (void* o, NIM_CHAR** s, NI* len);
typedef N_CDECL_PTR(void*, tyProc__YDKrw1adv61oVQkQhbYyaA) (NCSTRING s);
typedef N_CDECL_PTR(int, tyProc__B2MjSeo07a72ynTQRVYFKw) (void* o, NCSTRING s);
typedef N_CDECL_PTR(NCSTRING, tyProc__p1X2BwWx9a3wsChhykvf29aA) (void* o);
typedef N_CDECL_PTR(void*, tyProc__NzboHqZVJcbdtVGYrOosXQ) (void);
typedef N_CDECL_PTR(int, tyProc__MTei9bsKjha0o1cISO9aLMDg) (void* o, void* k);
typedef N_NIMCALL_PTR(void, tyProc__4SVlZZPmetqBimNsH9cHcOA) (void* o);
typedef N_CDECL_PTR(void, tyProc__ln4kdL5W9bbX4a1xl8nnVXQ) (void);
typedef N_CDECL_PTR(void, tyProc__WYY8i0I79agBofnUcEGCfig) (void* o, NCSTRING s);
typedef N_CDECL_PTR(void, tyProc__32w2ZypAyMWuajvi2Jt79cg) (void* o);
typedef N_CDECL_PTR(void*, tyProc__jcEovQ2rZUNUsYxohT50Ug) (void* p, NCSTRING name, tyProc__32w2ZypAyMWuajvi2Jt79cg destr);
typedef N_CDECL_PTR(void*, tyProc__9b2qzlf3LCKK0JvThQT1atg) (tyObject_PyMethodDef__9aWi1PsmvCuTKIYDHHnhfcw* md, void* self, void* module);
struct tyTuple__47w2DboNEPf69aPgubZdd7Q {
NI Field0;
NI Field1;
NI Field2;
};
typedef N_CDECL_PTR(void, tyProc__U0oVFt576Ze44Q9a3eZc5wg) (void** ptype, void** pvalue, void** ptraceback);
struct tyObject_PyLibcolonObjectType___bTw708kK89b8Vj9cmSu9a4zig {
void* module;
tyProc__SsjMo29bx9bP5kwe2xgM3Scg Py_BuildValue;
tyProc__4wJmT85lsn175X0dPNQv7w PyTuple_New;
tyProc__YRQqZC12s3573tRGP8MV3g PyTuple_Size;
tyProc__oPIasAghCTvCKmvkMeB1xQ PyTuple_GetItem;
tyProc__6slETyyIDJuDOSqkO0hUXA PyTuple_SetItem;
void* Py_None;
tyProc__tgpXIILGoVcO9bvYnz9azTVQ PyType_Ready;
tyProc__eYT4U6bGFqFBUxk9b15mfOA PyType_GenericNew;
tyProc__T08W9bgbY4bOv2q64h6irpw PyModule_AddObject;
tyProc__4wJmT85lsn175X0dPNQv7w PyList_New;
tyProc__YRQqZC12s3573tRGP8MV3g PyList_Size;
tyProc__oPIasAghCTvCKmvkMeB1xQ PyList_GetItem;
tyProc__6slETyyIDJuDOSqkO0hUXA PyList_SetItem;
tyProc__uQWqJp3WAx8fOY1h9aCwjIg PyObject_Call;
tyProc__fbYpjfe38x3ujjAmVRbI1Q PyObject_IsTrue;
tyProc__YezmFzxOOyM9cb11Eoq1Elg PyObject_GetAttrString;
tyProc__T08W9bgbY4bOv2q64h6irpw PyObject_SetAttrString;
tyProc__jvPpjMAkI9bwM1B9apOphnlA PyObject_Dir;
tyProc__jvPpjMAkI9bwM1B9apOphnlA PyObject_Str;
tyProc__jvPpjMAkI9bwM1B9apOphnlA PyObject_GetIter;
tyProc__VQ1ysQk017myXMGb79cPTVw PyObject_GetItem;
tyProc__7LMjBc4zOHVIsNdulNv7QQ PyObject_SetItem;
tyProc__eoRP3F9aLT3mtHj6OkcMSyQ PyObject_RichCompareBool;
tyProc__8hR9arLDkUs9ag3Pt9bWtjfsg PyObject_GetBuffer;
tyProc__vFvpnKOere9bRFN9czzMRlTA PyBuffer_Release;
tyProc__BZ6N5NNdHcK05FTDxQbEWw PyErr_NewException;
tyProc__jvPpjMAkI9bwM1B9apOphnlA PyIter_Next;
tyProc__jvPpjMAkI9bwM1B9apOphnlA PyNumber_Long;
tyProc__mIlNZ9aGaphVJCyIIofK8mg PyLong_AsLongLong;
tyProc__9b5I9aMvpc2qfvARBMMx9blAg PyLong_AsUnsignedLongLong;
tyProc__2su9b9chqHYibM7sMkbSaSkA PyFloat_AsDouble;
tyProc__RKlUmjvtmKGnc01PbvZaRQ PyBool_FromLong;
tyObject_PyTypeObject3Obj__cRsC9bGvH9bX6A9aVx8UB6I5g* PyBool_Type;
tyObject_PyTypeObject3Obj__cRsC9bGvH9bX6A9aVx8UB6I5g* PyFloat_Type;
tyObject_PyTypeObject3Obj__cRsC9bGvH9bX6A9aVx8UB6I5g* PyComplex_Type;
tyObject_PyTypeObject3Obj__cRsC9bGvH9bX6A9aVx8UB6I5g* PyCapsule_Type;
tyObject_PyTypeObject3Obj__cRsC9bGvH9bX6A9aVx8UB6I5g* PyTuple_Type;
tyObject_PyTypeObject3Obj__cRsC9bGvH9bX6A9aVx8UB6I5g* PyList_Type;
tyObject_PyTypeObject3Obj__cRsC9bGvH9bX6A9aVx8UB6I5g* PyBytes_Type;
tyObject_PyTypeObject3Obj__cRsC9bGvH9bX6A9aVx8UB6I5g* PyUnicode_Type;
tyObject_PyTypeObject3Obj__cRsC9bGvH9bX6A9aVx8UB6I5g* PySuper_Type;
tyProc__i2exZ7Vtp648U9crOFcq9beQ PyType_IsSubtype;
tyProc__N1A5ZvDSgO9c9aRXmVqfn9bAw PyComplex_AsCComplex;
tyProc__2su9b9chqHYibM7sMkbSaSkA PyComplex_RealAsDouble;
tyProc__2su9b9chqHYibM7sMkbSaSkA PyComplex_ImagAsDouble;
tyProc__jvPpjMAkI9bwM1B9apOphnlA PyUnicode_AsUTF8String;
tyProc__6esIxH9aNBn9aNzK4x86GkYw PyBytes_FromStringAndSize;
tyProc__3FKLKFzOaK7FD6dRLWM6Jw PyBytes_AsStringAndSize;
tyProc__YDKrw1adv61oVQkQhbYyaA PyUnicode_FromString;
tyProc__B2MjSeo07a72ynTQRVYFKw PyUnicode_CompareWithASCIIString;
tyProc__p1X2BwWx9a3wsChhykvf29aA PyString_AsString;
tyObject_PyTypeObject3Obj__cRsC9bGvH9bX6A9aVx8UB6I5g* PyDict_Type;
tyProc__NzboHqZVJcbdtVGYrOosXQ PyDict_New;
tyProc__YRQqZC12s3573tRGP8MV3g PyDict_Size;
tyProc__YezmFzxOOyM9cb11Eoq1Elg PyDict_GetItemString;
tyProc__T08W9bgbY4bOv2q64h6irpw PyDict_SetItemString;
tyProc__VQ1ysQk017myXMGb79cPTVw PyDict_GetItem;
tyProc__7LMjBc4zOHVIsNdulNv7QQ PyDict_SetItem;
tyProc__jvPpjMAkI9bwM1B9apOphnlA PyDict_Keys;
tyProc__jvPpjMAkI9bwM1B9apOphnlA PyDict_Values;
tyProc__MTei9bsKjha0o1cISO9aLMDg PyDict_Contains;
tyProc__4SVlZZPmetqBimNsH9cHcOA PyDealloc;
tyProc__ln4kdL5W9bbX4a1xl8nnVXQ PyErr_Clear;
tyProc__WYY8i0I79agBofnUcEGCfig PyErr_SetString;
tyProc__NzboHqZVJcbdtVGYrOosXQ PyErr_Occurred;
void* PyExc_TypeError;
tyProc__jcEovQ2rZUNUsYxohT50Ug PyCapsule_New;
tyProc__YezmFzxOOyM9cb11Eoq1Elg PyCapsule_GetPointer;
tyProc__YDKrw1adv61oVQkQhbYyaA PyImport_ImportModule;
tyProc__NzboHqZVJcbdtVGYrOosXQ PyEval_GetBuiltins;
tyProc__NzboHqZVJcbdtVGYrOosXQ PyEval_GetGlobals;
tyProc__NzboHqZVJcbdtVGYrOosXQ PyEval_GetLocals;
tyProc__9b2qzlf3LCKK0JvThQT1atg PyCFunction_NewEx;
tyTuple__47w2DboNEPf69aPgubZdd7Q pythonVersion;
tyProc__ln4kdL5W9bbX4a1xl8nnVXQ PyErr_Print;
tyProc__U0oVFt576Ze44Q9a3eZc5wg PyErr_Fetch;
tyProc__U0oVFt576Ze44Q9a3eZc5wg PyErr_NormalizeException;
tyProc__MTei9bsKjha0o1cISO9aLMDg PyErr_GivenExceptionMatches;
void* PyExc_BaseException;
void* PyExc_Exception;
void* PyExc_ArithmeticError;
void* PyExc_FloatingPointError;
void* PyExc_OverflowError;
void* PyExc_ZeroDivisionError;
void* PyExc_AssertionError;
void* PyExc_OSError;
void* PyExc_IOError;
void* PyExc_ValueError;
void* PyExc_EOFError;
void* PyExc_MemoryError;
void* PyExc_IndexError;
void* PyExc_KeyError;
void* NimPyException;
};
typedef N_CDECL_PTR(NCSTRING, tyProc__09bvyvHFtWbkzL5AHgf0bKw) (void);
struct RootObj {
TNimType* m_type;
};
struct Exception {
  RootObj Sup;
Exception* parent;
NCSTRING name;
NimStringDesc* message;
tySequence__uB9b75OUPRENsBAu4AnoePA* trace;
Exception* up;
};
struct tyObject_CatchableError__qrLSDoe2oBoAqNtJ9badtnA {
  Exception Sup;
};
struct tyObject_ValueError__yoNlBGx0D2tRizIdhQuENw {
  tyObject_CatchableError__qrLSDoe2oBoAqNtJ9badtnA Sup;
};
struct tyObject_PyObjectObj__aD5pkFWInXrZXinZ42cDEg {
NI ob_refcnt;
void* ob_type;
};
struct tyObject_PyObjectVarHeadObj__5fAkl5kIcYJNl6VvYzZdMw {
  tyObject_PyObjectObj__aD5pkFWInXrZXinZ42cDEg Sup;
NI ob_size;
};
typedef N_CDECL_PTR(int, tyProc__rNiGphbUW4RHd2WIj64deg) (void* o, FILE* f, int c);
typedef N_CDECL_PTR(void*, tyProc__k4RBH32nrpDxtGF9acg45zw) (void* a, void* b, int c);
typedef N_CDECL_PTR(void*, tyProc__Cj3MN9a7OA9a51xOtsYjEwBg) (tyObject_PyTypeObject3Obj__cRsC9bGvH9bX6A9aVx8UB6I5g* typ, NI sz);
typedef N_CDECL_PTR(void*, tyProc__3hYcL7bVv9cte9aw9aoXtthhA) (void* c, void** args, size_t nargs, void* kwnames);
struct tyObject_PyTypeObject3Obj__cRsC9bGvH9bX6A9aVx8UB6I5g {
  tyObject_PyObjectVarHeadObj__5fAkl5kIcYJNl6VvYzZdMw Sup;
NCSTRING tp_name;
NI tp_basicsize;
NI tp_itemsize;
tyProc__32w2ZypAyMWuajvi2Jt79cg tp_dealloc;
tyProc__rNiGphbUW4RHd2WIj64deg tp_print;
tyProc__YezmFzxOOyM9cb11Eoq1Elg tp_getattr;
tyProc__T08W9bgbY4bOv2q64h6irpw tp_setattr;
void* tp_as_async;
tyProc__jvPpjMAkI9bwM1B9apOphnlA tp_repr;
void* tp_as_number;
void* tp_as_sequence;
void* tp_as_mapping;
void* tp_hash;
void* tp_call;
tyProc__jvPpjMAkI9bwM1B9apOphnlA tp_str;
tyProc__VQ1ysQk017myXMGb79cPTVw tp_getattro;
tyProc__7LMjBc4zOHVIsNdulNv7QQ tp_setattro;
void* tp_as_buffer;
unsigned long tp_flags;
NCSTRING tp_doc;
void* tp_traverse;
void* tp_clear;
tyProc__k4RBH32nrpDxtGF9acg45zw tp_richcompare;
NI tp_weaklistoffset;
tyProc__jvPpjMAkI9bwM1B9apOphnlA tp_iter;
tyProc__jvPpjMAkI9bwM1B9apOphnlA tp_iternext;
tyObject_PyMethodDef__9aWi1PsmvCuTKIYDHHnhfcw* tp_methods;
tyObject_PyMemberDef__WC29aEeHi2Pdy9c4AkllcBTg* tp_members;
void* tp_getset;
tyObject_PyTypeObject3Obj__cRsC9bGvH9bX6A9aVx8UB6I5g* tp_base;
void* tp_dict;
tyProc__uQWqJp3WAx8fOY1h9aCwjIg tp_descr_get;
tyProc__7LMjBc4zOHVIsNdulNv7QQ tp_descr_set;
NI tp_dictoffset;
tyProc__7LMjBc4zOHVIsNdulNv7QQ tp_init;
tyProc__Cj3MN9a7OA9a51xOtsYjEwBg tp_alloc;
tyProc__eYT4U6bGFqFBUxk9b15mfOA tp_new;
tyProc__32w2ZypAyMWuajvi2Jt79cg tp_free;
void* tp_is_gc;
tyObject_PyObjectObj__aD5pkFWInXrZXinZ42cDEg* tp_bases;
void* tp_mro;
void* tp_cache;
tyObject_PyObjectObj__aD5pkFWInXrZXinZ42cDEg* tp_subclasses;
tyObject_PyObjectObj__aD5pkFWInXrZXinZ42cDEg* tp_weaklist;
tyProc__32w2ZypAyMWuajvi2Jt79cg tp_del;
unsigned int tp_version_tag;
tyProc__32w2ZypAyMWuajvi2Jt79cg tp_finalize;
tyProc__3hYcL7bVv9cte9aw9aoXtthhA tp_vectorcall;
};
typedef N_STDCALL_PTR(NI32, tyProc__Ph37G33p2ec6K0xFeDk1cQ) (NI hProcess, void** lphModule, NI32 cb, NI32* cbNeeded);
struct tyObject_StackTraceEntry__oLyohQ7O2XOvGnflOss8EA {
NCSTRING procname;
NI line;
NCSTRING filename;
};
struct tySequence__M73GJ9bOx1XdoIRnhIyhqTQ {
  TGenericSeq Sup;
  tyObject_ExportedModule__fxDBwb9c9c8NsdRe9bmg8Q9a2A data[SEQ_DECL_SIZE];
};
struct tySequence__uB9b75OUPRENsBAu4AnoePA {
  TGenericSeq Sup;
  tyObject_StackTraceEntry__oLyohQ7O2XOvGnflOss8EA data[SEQ_DECL_SIZE];
};
N_LIB_PRIVATE N_NIMCALL(void, nimGCvisit)(void* d, NI op);
static N_NIMCALL(void, Marker_tySequence__M73GJ9bOx1XdoIRnhIyhqTQ)(void* p, NI op);
static N_NIMCALL(void, TM__XnAUe69cYg8yQhnmiRJUnHw_3)(void);
N_LIB_PRIVATE N_NIMCALL(void, nimRegisterGlobalMarker)(tyProc__T4eqaYlFJYZUv9aG9b1TV0bQ markerProc);
static N_INLINE(void, nimGCunrefRC1)(void* p);
static N_INLINE(void, decRef__system_5432)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c);
static N_INLINE(NI, minuspercent___system_716)(NI x, NI y);
static N_INLINE(void, nimFrame)(TFrame* s);
N_LIB_PRIVATE N_NOINLINE(void, callDepthLimitReached__system_3012)(void);
static N_INLINE(void, popFrame)(void);
static N_INLINE(NIM_BOOL, ltpercent___system_1005)(NI x, NI y);
static N_INLINE(void, rtlAddZCT__system_5430)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c);
N_LIB_PRIVATE N_NOINLINE(void, addZCT__system_5381)(tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w* s, tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c);
static N_INLINE(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*, usrToCell__system_5387)(void* usr);
N_LIB_PRIVATE N_NIMCALL(void, failedAssertImpl__systemZassertions_56)(NimStringDesc* msg);
N_LIB_PRIVATE N_NOCONV(void*, allocShared0Impl__system_1758)(NI size);
N_LIB_PRIVATE N_NIMCALL(tyTuple__47w2DboNEPf69aPgubZdd7Q, getPyVersion__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_339)(void* pyLibHandle);
static N_INLINE(void, nimZeroMem)(void* p, NI size);
static N_INLINE(void, nimSetMem__systemZmemory_7)(void* a, int v, NI size);
N_LIB_PRIVATE N_NIMCALL(void*, symAddr__pureZdynlib_30)(void* lib, NCSTRING name);
N_LIB_PRIVATE N_NOINLINE(void*, newObj)(TNimType* typ, NI size);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, copyStringRC1)(NimStringDesc* src);
static N_INLINE(void, nimGCunrefNoCycle)(void* p);
static N_INLINE(void, asgnRef)(void** dest, void* src);
static N_INLINE(void, incRef__system_5425)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c);
static N_INLINE(NI, pluspercent___system_696)(NI x, NI y);
N_LIB_PRIVATE N_NIMCALL(void, raiseExceptionEx)(Exception* e, NCSTRING ename, NCSTRING procname, NCSTRING filename, NI line);
static N_INLINE(void, appendString)(NimStringDesc* dest, NimStringDesc* src);
static N_INLINE(void, copyMem__system_1727)(void* dest, void* source, NI size);
static N_INLINE(void, nimCopyMem)(void* dest, void* source, NI size);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, cstrToNimstr)(NCSTRING str);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, rawNewString)(NI space);
N_LIB_PRIVATE N_NIMCALL(void, symNotLoadedErr__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_336)(NCSTRING s);
N_LIB_PRIVATE N_NIMCALL(void, deallocPythonObj__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_629)(void* p);
static N_INLINE(tyObject_PyObjectObj__aD5pkFWInXrZXinZ42cDEg*, to__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_632)(void* p);
N_LIB_PRIVATE N_NIMCALL(void*, nimLoadLibrary)(NimStringDesc* path);
N_LIB_PRIVATE N_NIMCALL(void, nimLoadLibraryError)(NimStringDesc* path);
N_LIB_PRIVATE N_NIMCALL(void*, nimGetProcAddr)(void* lib, NCSTRING name);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, copyString)(NimStringDesc* src);
N_LIB_PRIVATE N_NIMCALL(TGenericSeq*, incrSeqV3)(TGenericSeq* s, TNimType* typ);
N_LIB_PRIVATE TNimType NTIexportedmodule__fxDBwb9c9c8NsdRe9bmg8Q9a2A_;
extern TNimType NTIstring__77mFvmsOLKik79ci2hXkHEg_;
extern TNimType NTIpointer__vr5DoT1jILTGdRlYv1OYpw_;
N_LIB_PRIVATE TNimType NTIseqLexportedmoduleT__M73GJ9bOx1XdoIRnhIyhqTQ_;
STRING_LITERAL(TM__XnAUe69cYg8yQhnmiRJUnHw_4, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim(186, 9) `not m.isNil` ", 73);
extern TNimType NTIrefvalueerror__Ie1m0dv1ZHg72IgPRr1cDw_;
extern TNimType NTIvalueerror__yoNlBGx0D2tRizIdhQuENw_;
STRING_LITERAL(TM__XnAUe69cYg8yQhnmiRJUnHw_5, "Could not determine Python version", 34);
STRING_LITERAL(TM__XnAUe69cYg8yQhnmiRJUnHw_6, "Could not determine Python version: ", 36);
STRING_LITERAL(TM__XnAUe69cYg8yQhnmiRJUnHw_7, "Symbol not loaded: ", 19);
STRING_LITERAL(TM__XnAUe69cYg8yQhnmiRJUnHw_10, "kernel32", 8);
STRING_LITERAL(TM__XnAUe69cYg8yQhnmiRJUnHw_11, "kernel32", 8);
N_LIB_PRIVATE NU pyObjectStartOffset__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_278;
N_LIB_PRIVATE tyObject_PyLibcolonObjectType___bTw708kK89b8Vj9cmSu9a4zig* pyLib__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_279;
N_LIB_PRIVATE NIM_BOOL pyThreadFrameInited__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_280;
N_LIB_PRIVATE tySequence__M73GJ9bOx1XdoIRnhIyhqTQ* exportedModules__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_289;
extern TFrame* framePtr__system_2579;
extern TFrame* framePtr__system_2579;
extern TFrame* framePtr__system_2579;
extern TFrame* framePtr__system_2579;
extern TFrame* framePtr__system_2579;
extern TFrame* framePtr__system_2579;
extern tyObject_GcHeap__1TRH1TZMaVZTnLNcIHuNFQ gch__system_5334;
static void* TM__XnAUe69cYg8yQhnmiRJUnHw_8;
tyProc__Ph37G33p2ec6K0xFeDk1cQ Dl_1560282111_;
static N_NIMCALL(void, Marker_tySequence__M73GJ9bOx1XdoIRnhIyhqTQ)(void* p, NI op) {
	tySequence__M73GJ9bOx1XdoIRnhIyhqTQ* a;
	NI T1_;
	a = (tySequence__M73GJ9bOx1XdoIRnhIyhqTQ*)p;
	T1_ = (NI)0;
	for (T1_ = 0; T1_ < (a ? a->Sup.len : 0); T1_++) {
	nimGCvisit((void*)a->data[T1_].name, op);
	}
}
static N_NIMCALL(void, TM__XnAUe69cYg8yQhnmiRJUnHw_3)(void) {
	nimGCvisit((void*)exportedModules__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_289, 0);
}
static N_INLINE(void, nimFrame)(TFrame* s) {
	{
		if (!(framePtr__system_2579 == ((TFrame*) NIM_NIL))) goto LA3_;
		(*s).calldepth = ((NI16) 0);
	}
	goto LA1_;
	LA3_: ;
	{
		(*s).calldepth = (NI16)((*framePtr__system_2579).calldepth + ((NI16) 1));
	}
	LA1_: ;
	(*s).prev = framePtr__system_2579;
	framePtr__system_2579 = s;
	{
		if (!((*s).calldepth == ((NI16) 2000))) goto LA8_;
		callDepthLimitReached__system_3012();
	}
	LA8_: ;
}
static N_INLINE(void, popFrame)(void) {
	framePtr__system_2579 = (*framePtr__system_2579).prev;
}
static N_INLINE(NI, minuspercent___system_716)(NI x, NI y) {
	NI result;
	nimfr_("-%", "/home/gm/.choosenim/toolchains/nim-1.6.6/lib/system/arithmetics.nim");
	result = (NI)0;
	nimln_(414, "/home/gm/.choosenim/toolchains/nim-1.6.6/lib/system/arithmetics.nim");
	nimln_(418, "/home/gm/.choosenim/toolchains/nim-1.6.6/lib/system/arithmetics.nim");
	result = ((NI) ((NU)((NU32)(((NU) (x))) - (NU32)(((NU) (y))))));
	popFrame();
	return result;
}
static N_INLINE(NIM_BOOL, ltpercent___system_1005)(NI x, NI y) {
	NIM_BOOL result;
	nimfr_("<%", "/home/gm/.choosenim/toolchains/nim-1.6.6/lib/system/comparisons.nim");
	result = (NIM_BOOL)0;
	nimln_(186, "/home/gm/.choosenim/toolchains/nim-1.6.6/lib/system/comparisons.nim");
	nimln_(188, "/home/gm/.choosenim/toolchains/nim-1.6.6/lib/system/comparisons.nim");
	result = ((NU32)(((NU) (x))) < (NU32)(((NU) (y))));
	popFrame();
	return result;
}
static N_INLINE(void, rtlAddZCT__system_5430)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c) {
	nimfr_("rtlAddZCT", "/home/gm/.choosenim/toolchains/nim-1.6.6/lib/system/gc.nim");
	nimln_(243, "/home/gm/.choosenim/toolchains/nim-1.6.6/lib/system/gc.nim");
	addZCT__system_5381((&gch__system_5334.zct), c);
	popFrame();
}
static N_INLINE(void, decRef__system_5432)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c) {
	nimfr_("decRef", "/home/gm/.choosenim/toolchains/nim-1.6.6/lib/system/gc.nim");
	nimln_(248, "/home/gm/.choosenim/toolchains/nim-1.6.6/lib/system/gc.nim");
	(*c).refcount = minuspercent___system_716((*c).refcount, ((NI) 8));
	nimln_(249, "/home/gm/.choosenim/toolchains/nim-1.6.6/lib/system/gc.nim");
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = ltpercent___system_1005((*c).refcount, ((NI) 8));
		if (!T3_) goto LA4_;
		nimln_(250, "/home/gm/.choosenim/toolchains/nim-1.6.6/lib/system/gc.nim");
		rtlAddZCT__system_5430(c);
	}
	LA4_: ;
	popFrame();
}
static N_INLINE(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*, usrToCell__system_5387)(void* usr) {
	tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* result;
	NI T1_;
	nimfr_("usrToCell", "/home/gm/.choosenim/toolchains/nim-1.6.6/lib/system/gc.nim");
	result = (tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*)0;
	nimln_(177, "/home/gm/.choosenim/toolchains/nim-1.6.6/lib/system/gc.nim");
	T1_ = (NI)0;
	T1_ = minuspercent___system_716(((NI) (ptrdiff_t) (usr)), ((NI) 8));
	result = ((tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*) (T1_));
	popFrame();
	return result;
}
static N_INLINE(void, nimGCunrefRC1)(void* p) {
	tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* T1_;
	nimfr_("nimGCunrefRC1", "/home/gm/.choosenim/toolchains/nim-1.6.6/lib/system/gc.nim");
	nimln_(280, "/home/gm/.choosenim/toolchains/nim-1.6.6/lib/system/gc.nim");
	T1_ = (tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*)0;
	T1_ = usrToCell__system_5387(p);
	decRef__system_5432(T1_);
	popFrame();
}
static N_INLINE(void, nimSetMem__systemZmemory_7)(void* a, int v, NI size) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memset(a, v, ((size_t) (size)));
}
static N_INLINE(void, nimZeroMem)(void* p, NI size) {
	nimSetMem__systemZmemory_7(p, ((int) 0), size);
}
static N_INLINE(void, nimGCunrefNoCycle)(void* p) {
	tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* T1_;
	nimfr_("nimGCunrefNoCycle", "/home/gm/.choosenim/toolchains/nim-1.6.6/lib/system/gc.nim");
	nimln_(276, "/home/gm/.choosenim/toolchains/nim-1.6.6/lib/system/gc.nim");
	T1_ = (tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*)0;
	T1_ = usrToCell__system_5387(p);
	decRef__system_5432(T1_);
	popFrame();
}
static N_INLINE(NI, pluspercent___system_696)(NI x, NI y) {
	NI result;
	nimfr_("+%", "/home/gm/.choosenim/toolchains/nim-1.6.6/lib/system/arithmetics.nim");
	result = (NI)0;
	nimln_(403, "/home/gm/.choosenim/toolchains/nim-1.6.6/lib/system/arithmetics.nim");
	nimln_(407, "/home/gm/.choosenim/toolchains/nim-1.6.6/lib/system/arithmetics.nim");
	result = ((NI) ((NU)((NU32)(((NU) (x))) + (NU32)(((NU) (y))))));
	popFrame();
	return result;
}
static N_INLINE(void, incRef__system_5425)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c) {
	nimfr_("incRef", "/home/gm/.choosenim/toolchains/nim-1.6.6/lib/system/gc.nim");
	nimln_(231, "/home/gm/.choosenim/toolchains/nim-1.6.6/lib/system/gc.nim");
	(*c).refcount = pluspercent___system_696((*c).refcount, ((NI) 8));
	popFrame();
}
static N_INLINE(void, asgnRef)(void** dest, void* src) {
	nimfr_("asgnRef", "/home/gm/.choosenim/toolchains/nim-1.6.6/lib/system/gc.nim");
	nimln_(286, "/home/gm/.choosenim/toolchains/nim-1.6.6/lib/system/gc.nim");
	{
		tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* T5_;
		if (!!((src == NIM_NIL))) goto LA3_;
		T5_ = (tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*)0;
		T5_ = usrToCell__system_5387(src);
		incRef__system_5425(T5_);
	}
	LA3_: ;
	nimln_(287, "/home/gm/.choosenim/toolchains/nim-1.6.6/lib/system/gc.nim");
	{
		tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* T10_;
		if (!!(((*dest) == NIM_NIL))) goto LA8_;
		T10_ = (tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*)0;
		T10_ = usrToCell__system_5387((*dest));
		decRef__system_5432(T10_);
	}
	LA8_: ;
	nimln_(288, "/home/gm/.choosenim/toolchains/nim-1.6.6/lib/system/gc.nim");
	(*dest) = src;
	popFrame();
}
static N_INLINE(void, nimCopyMem)(void* dest, void* source, NI size) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memcpy(dest, source, ((size_t) (size)));
}
static N_INLINE(void, copyMem__system_1727)(void* dest, void* source, NI size) {
	nimCopyMem(dest, source, size);
}
static N_INLINE(void, appendString)(NimStringDesc* dest, NimStringDesc* src) {
	{
		if (!!((src == ((NimStringDesc*) NIM_NIL)))) goto LA3_;
		copyMem__system_1727(((void*) ((&(*dest).data[(*dest).Sup.len]))), ((void*) ((*src).data)), ((NI) ((NI)((*src).Sup.len + ((NI) 1)))));
		(*dest).Sup.len += (*src).Sup.len;
	}
	LA3_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyTuple__47w2DboNEPf69aPgubZdd7Q, getPyVersion__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_339)(void* pyLibHandle) {
	tyTuple__47w2DboNEPf69aPgubZdd7Q result;
	tyProc__09bvyvHFtWbkzL5AHgf0bKw pyVersionFuncPtr;
	void* T1_;
	NCSTRING pyVersion;
	int major;
	int minor;
	int micro;
	nimfr_("getPyVersion", "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	nimZeroMem((void*)(&result), sizeof(tyTuple__47w2DboNEPf69aPgubZdd7Q));
	nimln_(173, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	T1_ = (void*)0;
	T1_ = symAddr__pureZdynlib_30(pyLibHandle, "Py_GetVersion");
	pyVersionFuncPtr = ((tyProc__09bvyvHFtWbkzL5AHgf0bKw) (T1_));
	nimln_(174, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	{
		tyObject_ValueError__yoNlBGx0D2tRizIdhQuENw* T6_;
		NimStringDesc* T7_;
		if (!(pyVersionFuncPtr == 0)) goto LA4_;
		T6_ = NIM_NIL;
		T6_ = (tyObject_ValueError__yoNlBGx0D2tRizIdhQuENw*) newObj((&NTIrefvalueerror__Ie1m0dv1ZHg72IgPRr1cDw_), sizeof(tyObject_ValueError__yoNlBGx0D2tRizIdhQuENw));
		(*T6_).Sup.Sup.Sup.m_type = (&NTIvalueerror__yoNlBGx0D2tRizIdhQuENw_);
		(*T6_).Sup.Sup.name = "ValueError";
		T7_ = NIM_NIL;
		T7_ = (*T6_).Sup.Sup.message; (*T6_).Sup.Sup.message = copyStringRC1(((NimStringDesc*) &TM__XnAUe69cYg8yQhnmiRJUnHw_5));
		if (T7_) nimGCunrefNoCycle(T7_);
		asgnRef((void**) (&(*T6_).Sup.Sup.parent), ((Exception*) NIM_NIL));
		nimln_(175, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		raiseExceptionEx((Exception*)T6_, "ValueError", "getPyVersion", "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim", 175);
	}
	LA4_: ;
	nimln_(177, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	pyVersion = pyVersionFuncPtr();
	major = (int)0;
	minor = (int)0;
	micro = (int)0;
	nimln_(181, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	{
		int T10_;
		NIM_BOOL T11_;
		tyObject_ValueError__yoNlBGx0D2tRizIdhQuENw* T14_;
		NimStringDesc* T15_;
		NimStringDesc* T16_;
		nimln_(2117, "/home/gm/.choosenim/toolchains/nim-1.6.6/lib/system.nim");
		nimln_(181, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		T10_ = (int)0;
		T10_ = sscanf(pyVersion, "%d.%d.%d", (&major), (&minor), (&micro));
		nimln_(2117, "/home/gm/.choosenim/toolchains/nim-1.6.6/lib/system.nim");
		T11_ = (NIM_BOOL)0;
		T11_ = NIM_UNLIKELY((T10_ <= ((NI32) 0)));
		if (!T11_) goto LA12_;
		T14_ = NIM_NIL;
		T14_ = (tyObject_ValueError__yoNlBGx0D2tRizIdhQuENw*) newObj((&NTIrefvalueerror__Ie1m0dv1ZHg72IgPRr1cDw_), sizeof(tyObject_ValueError__yoNlBGx0D2tRizIdhQuENw));
		(*T14_).Sup.Sup.Sup.m_type = (&NTIvalueerror__yoNlBGx0D2tRizIdhQuENw_);
		(*T14_).Sup.Sup.name = "ValueError";
		nimln_(182, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		T15_ = NIM_NIL;
		T16_ = NIM_NIL;
		T16_ = cstrToNimstr(pyVersion);
		T15_ = rawNewString((T16_ ? T16_->Sup.len : 0) + 36);
appendString(T15_, ((NimStringDesc*) &TM__XnAUe69cYg8yQhnmiRJUnHw_6));
appendString(T15_, T16_);
		asgnRef((void**) (&(*T14_).Sup.Sup.message), T15_);
		asgnRef((void**) (&(*T14_).Sup.Sup.parent), ((Exception*) NIM_NIL));
		raiseExceptionEx((Exception*)T14_, "ValueError", "getPyVersion", "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim", 182);
	}
	LA12_: ;
	result.Field0 = ((NI) (major));
	result.Field1 = ((NI) (minor));
	result.Field2 = ((NI) (micro));
	popFrame();
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, symNotLoadedErr__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_336)(NCSTRING s) {
	tyObject_ValueError__yoNlBGx0D2tRizIdhQuENw* T1_;
	NimStringDesc* T2_;
	NimStringDesc* T3_;
	nimfr_("symNotLoadedErr", "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	T1_ = NIM_NIL;
	T1_ = (tyObject_ValueError__yoNlBGx0D2tRizIdhQuENw*) newObj((&NTIrefvalueerror__Ie1m0dv1ZHg72IgPRr1cDw_), sizeof(tyObject_ValueError__yoNlBGx0D2tRizIdhQuENw));
	(*T1_).Sup.Sup.Sup.m_type = (&NTIvalueerror__yoNlBGx0D2tRizIdhQuENw_);
	(*T1_).Sup.Sup.name = "ValueError";
	nimln_(162, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	T2_ = NIM_NIL;
	T3_ = NIM_NIL;
	T3_ = cstrToNimstr(s);
	T2_ = rawNewString((T3_ ? T3_->Sup.len : 0) + 19);
appendString(T2_, ((NimStringDesc*) &TM__XnAUe69cYg8yQhnmiRJUnHw_7));
appendString(T2_, T3_);
	asgnRef((void**) (&(*T1_).Sup.Sup.message), T2_);
	asgnRef((void**) (&(*T1_).Sup.Sup.parent), ((Exception*) NIM_NIL));
	raiseExceptionEx((Exception*)T1_, "ValueError", "symNotLoadedErr", "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim", 162);
	popFrame();
}
static N_INLINE(tyObject_PyObjectObj__aD5pkFWInXrZXinZ42cDEg*, to__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_632)(void* p) {
	tyObject_PyObjectObj__aD5pkFWInXrZXinZ42cDEg* result;
	nimfr_("to", "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	result = (tyObject_PyObjectObj__aD5pkFWInXrZXinZ42cDEg*)0;
	nimln_(154, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	result = ((tyObject_PyObjectObj__aD5pkFWInXrZXinZ42cDEg*) ((NU)((NU32)(((NU) (ptrdiff_t) (p))) + (NU32)(pyObjectStartOffset__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_278))));
	popFrame();
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, deallocPythonObj__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_629)(void* p) {
	tyObject_PyObjectObj__aD5pkFWInXrZXinZ42cDEg* ob;
	tyObject_PyTypeObject3Obj__cRsC9bGvH9bX6A9aVx8UB6I5g* t;
	nimfr_("deallocPythonObj", "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	nimln_(157, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	ob = to__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_632(p);
	nimln_(158, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	t = ((tyObject_PyTypeObject3Obj__cRsC9bGvH9bX6A9aVx8UB6I5g*) ((*ob).ob_type));
	nimln_(159, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	(*t).tp_dealloc(((void*) (p)));
	popFrame();
}
N_LIB_PRIVATE N_NIMCALL(tyObject_PyLibcolonObjectType___bTw708kK89b8Vj9cmSu9a4zig*, loadPyLibFromModule__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_377)(void* m) {
	tyObject_PyLibcolonObjectType___bTw708kK89b8Vj9cmSu9a4zig* result;
	void* T5_;
	tyObject_PyLibcolonObjectType___bTw708kK89b8Vj9cmSu9a4zig* pl;
	void* T17_;
	void* T22_;
	void* T27_;
	void* T32_;
	void* T37_;
	void* T42_;
	void* T47_;
	void* T52_;
	void* T57_;
	void* T62_;
	void* T67_;
	void* T72_;
	void* T77_;
	void* T82_;
	void* T87_;
	void* T92_;
	void* T97_;
	void* T102_;
	void* T107_;
	void* T112_;
	void* T117_;
	void* T122_;
	void* T127_;
	void* T132_;
	void* T133_;
	void* T134_;
	void* T139_;
	void* T144_;
	void* T149_;
	void* T154_;
	void* T159_;
	void* T164_;
	void* T169_;
	void* T174_;
	void* T179_;
	void* T184_;
	void* T189_;
	void* T194_;
	void* T199_;
	void* T204_;
	void* T214_;
	void* T224_;
	void* T229_;
	void* T244_;
	void* T254_;
	void* T269_;
	void* T270_;
	void* T285_;
	void* T290_;
	void* T295_;
	void* T300_;
	void* T305_;
	void* T310_;
	void* T315_;
	void* T320_;
	void* T325_;
	void* T330_;
	void* T335_;
	void* T340_;
	void* T345_;
	void* T350_;
	void* T355_;
	void* T360_;
	void* T365_;
	void* T370_;
	void* T375_;
	void* T380_;
	void* T385_;
	void* T390_;
	void* T395_;
	void* T400_;
	void* T405_;
	void* T410_;
	void* T415_;
	void* T420_;
	void* T425_;
	void* T430_;
	void* T435_;
	void* T440_;
	void* T445_;
	void* T450_;
	void* T455_;
	void* T460_;
	void* T465_;
	void* T470_;
	nimfr_("loadPyLibFromModule", "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	result = (tyObject_PyLibcolonObjectType___bTw708kK89b8Vj9cmSu9a4zig*)0;
	nimln_(186, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	{
		if (!!(!((m == 0)))) goto LA3_;
		failedAssertImpl__systemZassertions_56(((NimStringDesc*) &TM__XnAUe69cYg8yQhnmiRJUnHw_4));
	}
	LA3_: ;
	nimln_(187, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	T5_ = (void*)0;
	T5_ = allocShared0Impl__system_1758(((NI) 384));
	result = ((tyObject_PyLibcolonObjectType___bTw708kK89b8Vj9cmSu9a4zig*) (T5_));
	nimln_(188, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	pl = result;
	nimln_(189, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	(*pl).module = m;
	nimln_(190, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	(*pl).pythonVersion = getPyVersion__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_339(m);
	nimln_(192, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	{
		NIM_BOOL T8_;
		NIM_BOOL T9_;
		void* T10_;
		void* T12_;
		void* T14_;
		nimln_(193, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		T8_ = (NIM_BOOL)0;
		nimln_(192, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		T9_ = (NIM_BOOL)0;
		T10_ = (void*)0;
		T10_ = symAddr__pureZdynlib_30(m, "PyModule_Create2");
		T9_ = (T10_ == 0);
		if (T9_) goto LA11_;
		nimln_(193, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		T12_ = (void*)0;
		T12_ = symAddr__pureZdynlib_30(m, "Py_InitModule4_64");
		T9_ = (T12_ == 0);
		LA11_: ;
		T8_ = T9_;
		if (T8_) goto LA13_;
		nimln_(194, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		T14_ = (void*)0;
		T14_ = symAddr__pureZdynlib_30(m, "Py_InitModule4");
		T8_ = (T14_ == 0);
		LA13_: ;
		if (!!(T8_)) goto LA15_;
		nimln_(196, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		pyObjectStartOffset__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_278 = ((NU) 8);
	}
	LA15_: ;
	nimln_(199, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	T17_ = (void*)0;
	T17_ = symAddr__pureZdynlib_30(m, "_Py_BuildValue_SizeT");
	(*pl).Py_BuildValue = ((tyProc__SsjMo29bx9bP5kwe2xgM3Scg) (T17_));
	nimln_(213, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	{
		nimln_(203, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		if (!((*pl).Py_BuildValue == 0)) goto LA20_;
		nimln_(204, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		symNotLoadedErr__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_336("_Py_BuildValue_SizeT");
	}
	LA20_: ;
	nimln_(199, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	T22_ = (void*)0;
	T22_ = symAddr__pureZdynlib_30(m, "PyTuple_New");
	(*pl).PyTuple_New = ((tyProc__4wJmT85lsn175X0dPNQv7w) (T22_));
	nimln_(214, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	{
		nimln_(203, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		if (!((*pl).PyTuple_New == 0)) goto LA25_;
		nimln_(204, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		symNotLoadedErr__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_336("PyTuple_New");
	}
	LA25_: ;
	nimln_(199, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	T27_ = (void*)0;
	T27_ = symAddr__pureZdynlib_30(m, "PyTuple_Size");
	(*pl).PyTuple_Size = ((tyProc__YRQqZC12s3573tRGP8MV3g) (T27_));
	nimln_(215, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	{
		nimln_(203, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		if (!((*pl).PyTuple_Size == 0)) goto LA30_;
		nimln_(204, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		symNotLoadedErr__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_336("PyTuple_Size");
	}
	LA30_: ;
	nimln_(199, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	T32_ = (void*)0;
	T32_ = symAddr__pureZdynlib_30(m, "PyTuple_GetItem");
	(*pl).PyTuple_GetItem = ((tyProc__oPIasAghCTvCKmvkMeB1xQ) (T32_));
	nimln_(216, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	{
		nimln_(203, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		if (!((*pl).PyTuple_GetItem == 0)) goto LA35_;
		nimln_(204, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		symNotLoadedErr__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_336("PyTuple_GetItem");
	}
	LA35_: ;
	nimln_(199, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	T37_ = (void*)0;
	T37_ = symAddr__pureZdynlib_30(m, "PyTuple_SetItem");
	(*pl).PyTuple_SetItem = ((tyProc__6slETyyIDJuDOSqkO0hUXA) (T37_));
	nimln_(217, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	{
		nimln_(203, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		if (!((*pl).PyTuple_SetItem == 0)) goto LA40_;
		nimln_(204, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		symNotLoadedErr__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_336("PyTuple_SetItem");
	}
	LA40_: ;
	nimln_(199, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	T42_ = (void*)0;
	T42_ = symAddr__pureZdynlib_30(m, "_Py_NoneStruct");
	(*pl).Py_None = ((void*) (T42_));
	nimln_(219, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	{
		nimln_(203, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		if (!((*pl).Py_None == 0)) goto LA45_;
		nimln_(204, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		symNotLoadedErr__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_336("_Py_NoneStruct");
	}
	LA45_: ;
	nimln_(199, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	T47_ = (void*)0;
	T47_ = symAddr__pureZdynlib_30(m, "PyType_Ready");
	(*pl).PyType_Ready = ((tyProc__tgpXIILGoVcO9bvYnz9azTVQ) (T47_));
	nimln_(220, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	{
		nimln_(203, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		if (!((*pl).PyType_Ready == 0)) goto LA50_;
		nimln_(204, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		symNotLoadedErr__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_336("PyType_Ready");
	}
	LA50_: ;
	nimln_(199, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	T52_ = (void*)0;
	T52_ = symAddr__pureZdynlib_30(m, "PyType_GenericNew");
	(*pl).PyType_GenericNew = ((tyProc__eYT4U6bGFqFBUxk9b15mfOA) (T52_));
	nimln_(221, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	{
		nimln_(203, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		if (!((*pl).PyType_GenericNew == 0)) goto LA55_;
		nimln_(204, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		symNotLoadedErr__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_336("PyType_GenericNew");
	}
	LA55_: ;
	nimln_(199, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	T57_ = (void*)0;
	T57_ = symAddr__pureZdynlib_30(m, "PyModule_AddObject");
	(*pl).PyModule_AddObject = ((tyProc__T08W9bgbY4bOv2q64h6irpw) (T57_));
	nimln_(222, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	{
		nimln_(203, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		if (!((*pl).PyModule_AddObject == 0)) goto LA60_;
		nimln_(204, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		symNotLoadedErr__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_336("PyModule_AddObject");
	}
	LA60_: ;
	nimln_(199, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	T62_ = (void*)0;
	T62_ = symAddr__pureZdynlib_30(m, "PyList_New");
	(*pl).PyList_New = ((tyProc__4wJmT85lsn175X0dPNQv7w) (T62_));
	nimln_(224, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	{
		nimln_(203, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		if (!((*pl).PyList_New == 0)) goto LA65_;
		nimln_(204, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		symNotLoadedErr__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_336("PyList_New");
	}
	LA65_: ;
	nimln_(199, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	T67_ = (void*)0;
	T67_ = symAddr__pureZdynlib_30(m, "PyList_Size");
	(*pl).PyList_Size = ((tyProc__YRQqZC12s3573tRGP8MV3g) (T67_));
	nimln_(225, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	{
		nimln_(203, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		if (!((*pl).PyList_Size == 0)) goto LA70_;
		nimln_(204, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		symNotLoadedErr__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_336("PyList_Size");
	}
	LA70_: ;
	nimln_(199, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	T72_ = (void*)0;
	T72_ = symAddr__pureZdynlib_30(m, "PyList_GetItem");
	(*pl).PyList_GetItem = ((tyProc__oPIasAghCTvCKmvkMeB1xQ) (T72_));
	nimln_(226, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	{
		nimln_(203, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		if (!((*pl).PyList_GetItem == 0)) goto LA75_;
		nimln_(204, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		symNotLoadedErr__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_336("PyList_GetItem");
	}
	LA75_: ;
	nimln_(199, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	T77_ = (void*)0;
	T77_ = symAddr__pureZdynlib_30(m, "PyList_SetItem");
	(*pl).PyList_SetItem = ((tyProc__6slETyyIDJuDOSqkO0hUXA) (T77_));
	nimln_(227, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	{
		nimln_(203, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		if (!((*pl).PyList_SetItem == 0)) goto LA80_;
		nimln_(204, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		symNotLoadedErr__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_336("PyList_SetItem");
	}
	LA80_: ;
	nimln_(199, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	T82_ = (void*)0;
	T82_ = symAddr__pureZdynlib_30(m, "PyObject_Call");
	(*pl).PyObject_Call = ((tyProc__uQWqJp3WAx8fOY1h9aCwjIg) (T82_));
	nimln_(229, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	{
		nimln_(203, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		if (!((*pl).PyObject_Call == 0)) goto LA85_;
		nimln_(204, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		symNotLoadedErr__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_336("PyObject_Call");
	}
	LA85_: ;
	nimln_(199, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	T87_ = (void*)0;
	T87_ = symAddr__pureZdynlib_30(m, "PyObject_IsTrue");
	(*pl).PyObject_IsTrue = ((tyProc__fbYpjfe38x3ujjAmVRbI1Q) (T87_));
	nimln_(230, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	{
		nimln_(203, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		if (!((*pl).PyObject_IsTrue == 0)) goto LA90_;
		nimln_(204, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		symNotLoadedErr__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_336("PyObject_IsTrue");
	}
	LA90_: ;
	nimln_(199, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	T92_ = (void*)0;
	T92_ = symAddr__pureZdynlib_30(m, "PyObject_GetAttrString");
	(*pl).PyObject_GetAttrString = ((tyProc__YezmFzxOOyM9cb11Eoq1Elg) (T92_));
	nimln_(232, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	{
		nimln_(203, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		if (!((*pl).PyObject_GetAttrString == 0)) goto LA95_;
		nimln_(204, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		symNotLoadedErr__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_336("PyObject_GetAttrString");
	}
	LA95_: ;
	nimln_(199, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	T97_ = (void*)0;
	T97_ = symAddr__pureZdynlib_30(m, "PyObject_SetAttrString");
	(*pl).PyObject_SetAttrString = ((tyProc__T08W9bgbY4bOv2q64h6irpw) (T97_));
	nimln_(233, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	{
		nimln_(203, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		if (!((*pl).PyObject_SetAttrString == 0)) goto LA100_;
		nimln_(204, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		symNotLoadedErr__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_336("PyObject_SetAttrString");
	}
	LA100_: ;
	nimln_(199, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	T102_ = (void*)0;
	T102_ = symAddr__pureZdynlib_30(m, "PyObject_Dir");
	(*pl).PyObject_Dir = ((tyProc__jvPpjMAkI9bwM1B9apOphnlA) (T102_));
	nimln_(234, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	{
		nimln_(203, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		if (!((*pl).PyObject_Dir == 0)) goto LA105_;
		nimln_(204, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		symNotLoadedErr__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_336("PyObject_Dir");
	}
	LA105_: ;
	nimln_(199, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	T107_ = (void*)0;
	T107_ = symAddr__pureZdynlib_30(m, "PyObject_Str");
	(*pl).PyObject_Str = ((tyProc__jvPpjMAkI9bwM1B9apOphnlA) (T107_));
	nimln_(235, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	{
		nimln_(203, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		if (!((*pl).PyObject_Str == 0)) goto LA110_;
		nimln_(204, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		symNotLoadedErr__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_336("PyObject_Str");
	}
	LA110_: ;
	nimln_(199, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	T112_ = (void*)0;
	T112_ = symAddr__pureZdynlib_30(m, "PyObject_GetIter");
	(*pl).PyObject_GetIter = ((tyProc__jvPpjMAkI9bwM1B9apOphnlA) (T112_));
	nimln_(236, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	{
		nimln_(203, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		if (!((*pl).PyObject_GetIter == 0)) goto LA115_;
		nimln_(204, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		symNotLoadedErr__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_336("PyObject_GetIter");
	}
	LA115_: ;
	nimln_(199, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	T117_ = (void*)0;
	T117_ = symAddr__pureZdynlib_30(m, "PyObject_GetItem");
	(*pl).PyObject_GetItem = ((tyProc__VQ1ysQk017myXMGb79cPTVw) (T117_));
	nimln_(237, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	{
		nimln_(203, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		if (!((*pl).PyObject_GetItem == 0)) goto LA120_;
		nimln_(204, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		symNotLoadedErr__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_336("PyObject_GetItem");
	}
	LA120_: ;
	nimln_(199, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	T122_ = (void*)0;
	T122_ = symAddr__pureZdynlib_30(m, "PyObject_SetItem");
	(*pl).PyObject_SetItem = ((tyProc__7LMjBc4zOHVIsNdulNv7QQ) (T122_));
	nimln_(238, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	{
		nimln_(203, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		if (!((*pl).PyObject_SetItem == 0)) goto LA125_;
		nimln_(204, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		symNotLoadedErr__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_336("PyObject_SetItem");
	}
	LA125_: ;
	nimln_(199, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	T127_ = (void*)0;
	T127_ = symAddr__pureZdynlib_30(m, "PyObject_RichCompareBool");
	(*pl).PyObject_RichCompareBool = ((tyProc__eoRP3F9aLT3mtHj6OkcMSyQ) (T127_));
	nimln_(239, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	{
		nimln_(203, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		if (!((*pl).PyObject_RichCompareBool == 0)) goto LA130_;
		nimln_(204, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		symNotLoadedErr__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_336("PyObject_RichCompareBool");
	}
	LA130_: ;
	nimln_(199, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	T132_ = (void*)0;
	T132_ = symAddr__pureZdynlib_30(m, "PyObject_GetBuffer");
	(*pl).PyObject_GetBuffer = ((tyProc__8hR9arLDkUs9ag3Pt9bWtjfsg) (T132_));
	T133_ = (void*)0;
	T133_ = symAddr__pureZdynlib_30(m, "PyBuffer_Release");
	(*pl).PyBuffer_Release = ((tyProc__vFvpnKOere9bRFN9czzMRlTA) (T133_));
	T134_ = (void*)0;
	T134_ = symAddr__pureZdynlib_30(m, "PyIter_Next");
	(*pl).PyIter_Next = ((tyProc__jvPpjMAkI9bwM1B9apOphnlA) (T134_));
	nimln_(244, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	{
		nimln_(203, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		if (!((*pl).PyIter_Next == 0)) goto LA137_;
		nimln_(204, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		symNotLoadedErr__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_336("PyIter_Next");
	}
	LA137_: ;
	nimln_(199, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	T139_ = (void*)0;
	T139_ = symAddr__pureZdynlib_30(m, "PyNumber_Long");
	(*pl).PyNumber_Long = ((tyProc__jvPpjMAkI9bwM1B9apOphnlA) (T139_));
	nimln_(246, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	{
		nimln_(203, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		if (!((*pl).PyNumber_Long == 0)) goto LA142_;
		nimln_(204, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		symNotLoadedErr__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_336("PyNumber_Long");
	}
	LA142_: ;
	nimln_(199, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	T144_ = (void*)0;
	T144_ = symAddr__pureZdynlib_30(m, "PyLong_AsLongLong");
	(*pl).PyLong_AsLongLong = ((tyProc__mIlNZ9aGaphVJCyIIofK8mg) (T144_));
	nimln_(247, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	{
		nimln_(203, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		if (!((*pl).PyLong_AsLongLong == 0)) goto LA147_;
		nimln_(204, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		symNotLoadedErr__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_336("PyLong_AsLongLong");
	}
	LA147_: ;
	nimln_(199, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	T149_ = (void*)0;
	T149_ = symAddr__pureZdynlib_30(m, "PyLong_AsUnsignedLongLong");
	(*pl).PyLong_AsUnsignedLongLong = ((tyProc__9b5I9aMvpc2qfvARBMMx9blAg) (T149_));
	nimln_(248, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	{
		nimln_(203, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		if (!((*pl).PyLong_AsUnsignedLongLong == 0)) goto LA152_;
		nimln_(204, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		symNotLoadedErr__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_336("PyLong_AsUnsignedLongLong");
	}
	LA152_: ;
	nimln_(199, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	T154_ = (void*)0;
	T154_ = symAddr__pureZdynlib_30(m, "PyFloat_AsDouble");
	(*pl).PyFloat_AsDouble = ((tyProc__2su9b9chqHYibM7sMkbSaSkA) (T154_));
	nimln_(249, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	{
		nimln_(203, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		if (!((*pl).PyFloat_AsDouble == 0)) goto LA157_;
		nimln_(204, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		symNotLoadedErr__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_336("PyFloat_AsDouble");
	}
	LA157_: ;
	nimln_(199, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	T159_ = (void*)0;
	T159_ = symAddr__pureZdynlib_30(m, "PyBool_FromLong");
	(*pl).PyBool_FromLong = ((tyProc__RKlUmjvtmKGnc01PbvZaRQ) (T159_));
	nimln_(250, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	{
		nimln_(203, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		if (!((*pl).PyBool_FromLong == 0)) goto LA162_;
		nimln_(204, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		symNotLoadedErr__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_336("PyBool_FromLong");
	}
	LA162_: ;
	nimln_(199, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	T164_ = (void*)0;
	T164_ = symAddr__pureZdynlib_30(m, "PyBool_Type");
	(*pl).PyBool_Type = ((tyObject_PyTypeObject3Obj__cRsC9bGvH9bX6A9aVx8UB6I5g*) (T164_));
	nimln_(252, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	{
		nimln_(203, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		if (!((*pl).PyBool_Type == 0)) goto LA167_;
		nimln_(204, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		symNotLoadedErr__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_336("PyBool_Type");
	}
	LA167_: ;
	nimln_(199, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	T169_ = (void*)0;
	T169_ = symAddr__pureZdynlib_30(m, "PyFloat_Type");
	(*pl).PyFloat_Type = ((tyObject_PyTypeObject3Obj__cRsC9bGvH9bX6A9aVx8UB6I5g*) (T169_));
	nimln_(253, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	{
		nimln_(203, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		if (!((*pl).PyFloat_Type == 0)) goto LA172_;
		nimln_(204, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		symNotLoadedErr__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_336("PyFloat_Type");
	}
	LA172_: ;
	nimln_(199, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	T174_ = (void*)0;
	T174_ = symAddr__pureZdynlib_30(m, "PyComplex_Type");
	(*pl).PyComplex_Type = ((tyObject_PyTypeObject3Obj__cRsC9bGvH9bX6A9aVx8UB6I5g*) (T174_));
	nimln_(254, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	{
		nimln_(203, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		if (!((*pl).PyComplex_Type == 0)) goto LA177_;
		nimln_(204, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		symNotLoadedErr__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_336("PyComplex_Type");
	}
	LA177_: ;
	nimln_(199, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	T179_ = (void*)0;
	T179_ = symAddr__pureZdynlib_30(m, "PyCapsule_Type");
	(*pl).PyCapsule_Type = ((tyObject_PyTypeObject3Obj__cRsC9bGvH9bX6A9aVx8UB6I5g*) (T179_));
	nimln_(255, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	{
		nimln_(203, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		if (!((*pl).PyCapsule_Type == 0)) goto LA182_;
		nimln_(204, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		symNotLoadedErr__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_336("PyCapsule_Type");
	}
	LA182_: ;
	nimln_(199, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	T184_ = (void*)0;
	T184_ = symAddr__pureZdynlib_30(m, "PyTuple_Type");
	(*pl).PyTuple_Type = ((tyObject_PyTypeObject3Obj__cRsC9bGvH9bX6A9aVx8UB6I5g*) (T184_));
	nimln_(256, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	{
		nimln_(203, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		if (!((*pl).PyTuple_Type == 0)) goto LA187_;
		nimln_(204, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		symNotLoadedErr__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_336("PyTuple_Type");
	}
	LA187_: ;
	nimln_(199, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	T189_ = (void*)0;
	T189_ = symAddr__pureZdynlib_30(m, "PyList_Type");
	(*pl).PyList_Type = ((tyObject_PyTypeObject3Obj__cRsC9bGvH9bX6A9aVx8UB6I5g*) (T189_));
	nimln_(257, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	{
		nimln_(203, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		if (!((*pl).PyList_Type == 0)) goto LA192_;
		nimln_(204, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		symNotLoadedErr__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_336("PyList_Type");
	}
	LA192_: ;
	nimln_(199, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	T194_ = (void*)0;
	T194_ = symAddr__pureZdynlib_30(m, "PyUnicode_Type");
	(*pl).PyUnicode_Type = ((tyObject_PyTypeObject3Obj__cRsC9bGvH9bX6A9aVx8UB6I5g*) (T194_));
	nimln_(258, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	{
		nimln_(203, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		if (!((*pl).PyUnicode_Type == 0)) goto LA197_;
		nimln_(204, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		symNotLoadedErr__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_336("PyUnicode_Type");
	}
	LA197_: ;
	nimln_(199, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	T199_ = (void*)0;
	T199_ = symAddr__pureZdynlib_30(m, "PySuper_Type");
	(*pl).PySuper_Type = ((tyObject_PyTypeObject3Obj__cRsC9bGvH9bX6A9aVx8UB6I5g*) (T199_));
	nimln_(259, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	{
		nimln_(203, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		if (!((*pl).PySuper_Type == 0)) goto LA202_;
		nimln_(204, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		symNotLoadedErr__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_336("PySuper_Type");
	}
	LA202_: ;
	nimln_(199, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	T204_ = (void*)0;
	T204_ = symAddr__pureZdynlib_30(m, "PyBytes_Type");
	(*pl).PyBytes_Type = ((tyObject_PyTypeObject3Obj__cRsC9bGvH9bX6A9aVx8UB6I5g*) (T204_));
	nimln_(261, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	{
		void* T209_;
		if (!((*pl).PyBytes_Type == 0)) goto LA207_;
		nimln_(199, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		T209_ = (void*)0;
		T209_ = symAddr__pureZdynlib_30(m, "PyString_Type");
		(*pl).PyBytes_Type = ((tyObject_PyTypeObject3Obj__cRsC9bGvH9bX6A9aVx8UB6I5g*) (T209_));
		nimln_(263, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		{
			nimln_(203, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
			if (!((*pl).PyBytes_Type == 0)) goto LA212_;
			nimln_(204, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
			symNotLoadedErr__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_336("PyString_Type");
		}
		LA212_: ;
	}
	LA207_: ;
	nimln_(199, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	T214_ = (void*)0;
	T214_ = symAddr__pureZdynlib_30(m, "PyUnicode_FromString");
	(*pl).PyUnicode_FromString = ((tyProc__YDKrw1adv61oVQkQhbYyaA) (T214_));
	nimln_(267, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	{
		void* T219_;
		if (!((*pl).PyUnicode_FromString == 0)) goto LA217_;
		nimln_(199, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		T219_ = (void*)0;
		T219_ = symAddr__pureZdynlib_30(m, "PyString_FromString");
		(*pl).PyUnicode_FromString = ((tyProc__YDKrw1adv61oVQkQhbYyaA) (T219_));
		nimln_(268, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		{
			nimln_(203, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
			if (!((*pl).PyUnicode_FromString == 0)) goto LA222_;
			nimln_(204, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
			symNotLoadedErr__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_336("PyString_FromString");
		}
		LA222_: ;
	}
	LA217_: ;
	nimln_(199, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	T224_ = (void*)0;
	T224_ = symAddr__pureZdynlib_30(m, "PyType_IsSubtype");
	(*pl).PyType_IsSubtype = ((tyProc__i2exZ7Vtp648U9crOFcq9beQ) (T224_));
	nimln_(270, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	{
		nimln_(203, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		if (!((*pl).PyType_IsSubtype == 0)) goto LA227_;
		nimln_(204, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		symNotLoadedErr__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_336("PyType_IsSubtype");
	}
	LA227_: ;
	nimln_(199, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	T229_ = (void*)0;
	T229_ = symAddr__pureZdynlib_30(m, "PyComplex_AsCComplex");
	(*pl).PyComplex_AsCComplex = ((tyProc__N1A5ZvDSgO9c9aRXmVqfn9bAw) (T229_));
	nimln_(273, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	{
		void* T234_;
		void* T239_;
		if (!((*pl).PyComplex_AsCComplex == 0)) goto LA232_;
		nimln_(199, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		T234_ = (void*)0;
		T234_ = symAddr__pureZdynlib_30(m, "PyComplex_RealAsDouble");
		(*pl).PyComplex_RealAsDouble = ((tyProc__2su9b9chqHYibM7sMkbSaSkA) (T234_));
		nimln_(274, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		{
			nimln_(203, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
			if (!((*pl).PyComplex_RealAsDouble == 0)) goto LA237_;
			nimln_(204, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
			symNotLoadedErr__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_336("PyComplex_RealAsDouble");
		}
		LA237_: ;
		nimln_(199, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		T239_ = (void*)0;
		T239_ = symAddr__pureZdynlib_30(m, "PyComplex_ImagAsDouble");
		(*pl).PyComplex_ImagAsDouble = ((tyProc__2su9b9chqHYibM7sMkbSaSkA) (T239_));
		nimln_(275, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		{
			nimln_(203, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
			if (!((*pl).PyComplex_ImagAsDouble == 0)) goto LA242_;
			nimln_(204, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
			symNotLoadedErr__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_336("PyComplex_ImagAsDouble");
		}
		LA242_: ;
	}
	LA232_: ;
	nimln_(199, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	T244_ = (void*)0;
	T244_ = symAddr__pureZdynlib_30(m, "PyUnicode_CompareWithASCIIString");
	(*pl).PyUnicode_CompareWithASCIIString = ((tyProc__B2MjSeo07a72ynTQRVYFKw) (T244_));
	nimln_(278, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	{
		void* T249_;
		if (!((*pl).PyUnicode_CompareWithASCIIString == 0)) goto LA247_;
		nimln_(199, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		T249_ = (void*)0;
		T249_ = symAddr__pureZdynlib_30(m, "PyString_AsString");
		(*pl).PyString_AsString = ((tyProc__p1X2BwWx9a3wsChhykvf29aA) (T249_));
		nimln_(279, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		{
			nimln_(203, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
			if (!((*pl).PyString_AsString == 0)) goto LA252_;
			nimln_(204, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
			symNotLoadedErr__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_336("PyString_AsString");
		}
		LA252_: ;
	}
	LA247_: ;
	nimln_(199, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	T254_ = (void*)0;
	T254_ = symAddr__pureZdynlib_30(m, "PyUnicode_AsUTF8String");
	(*pl).PyUnicode_AsUTF8String = ((tyProc__jvPpjMAkI9bwM1B9apOphnlA) (T254_));
	nimln_(282, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	{
		void* T259_;
		if (!((*pl).PyUnicode_AsUTF8String == 0)) goto LA257_;
		nimln_(199, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		T259_ = (void*)0;
		T259_ = symAddr__pureZdynlib_30(m, "PyUnicodeUCS4_AsUTF8String");
		(*pl).PyUnicode_AsUTF8String = ((tyProc__jvPpjMAkI9bwM1B9apOphnlA) (T259_));
		nimln_(284, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		{
			void* T264_;
			if (!((*pl).PyUnicode_AsUTF8String == 0)) goto LA262_;
			nimln_(199, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
			T264_ = (void*)0;
			T264_ = symAddr__pureZdynlib_30(m, "PyUnicodeUCS2_AsUTF8String");
			(*pl).PyUnicode_AsUTF8String = ((tyProc__jvPpjMAkI9bwM1B9apOphnlA) (T264_));
			nimln_(285, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
			{
				nimln_(203, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
				if (!((*pl).PyUnicode_AsUTF8String == 0)) goto LA267_;
				nimln_(204, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
				symNotLoadedErr__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_336("PyUnicodeUCS2_AsUTF8String");
			}
			LA267_: ;
		}
		LA262_: ;
	}
	LA257_: ;
	nimln_(199, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	T269_ = (void*)0;
	T269_ = symAddr__pureZdynlib_30(m, "PyBytes_AsStringAndSize");
	(*pl).PyBytes_AsStringAndSize = ((tyProc__3FKLKFzOaK7FD6dRLWM6Jw) (T269_));
	T270_ = (void*)0;
	T270_ = symAddr__pureZdynlib_30(m, "PyBytes_FromStringAndSize");
	(*pl).PyBytes_FromStringAndSize = ((tyProc__6esIxH9aNBn9aNzK4x86GkYw) (T270_));
	nimln_(289, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	{
		void* T275_;
		void* T280_;
		if (!((*pl).PyBytes_AsStringAndSize == 0)) goto LA273_;
		nimln_(199, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		T275_ = (void*)0;
		T275_ = symAddr__pureZdynlib_30(m, "PyString_AsStringAndSize");
		(*pl).PyBytes_AsStringAndSize = ((tyProc__3FKLKFzOaK7FD6dRLWM6Jw) (T275_));
		nimln_(290, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		{
			nimln_(203, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
			if (!((*pl).PyBytes_AsStringAndSize == 0)) goto LA278_;
			nimln_(204, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
			symNotLoadedErr__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_336("PyString_AsStringAndSize");
		}
		LA278_: ;
		nimln_(199, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		T280_ = (void*)0;
		T280_ = symAddr__pureZdynlib_30(m, "PyString_FromStringAndSize");
		(*pl).PyBytes_FromStringAndSize = ((tyProc__6esIxH9aNBn9aNzK4x86GkYw) (T280_));
		nimln_(291, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		{
			nimln_(203, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
			if (!((*pl).PyBytes_FromStringAndSize == 0)) goto LA283_;
			nimln_(204, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
			symNotLoadedErr__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_336("PyString_FromStringAndSize");
		}
		LA283_: ;
	}
	LA273_: ;
	nimln_(199, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	T285_ = (void*)0;
	T285_ = symAddr__pureZdynlib_30(m, "PyDict_Type");
	(*pl).PyDict_Type = ((tyObject_PyTypeObject3Obj__cRsC9bGvH9bX6A9aVx8UB6I5g*) (T285_));
	nimln_(293, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	{
		nimln_(203, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		if (!((*pl).PyDict_Type == 0)) goto LA288_;
		nimln_(204, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		symNotLoadedErr__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_336("PyDict_Type");
	}
	LA288_: ;
	nimln_(199, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	T290_ = (void*)0;
	T290_ = symAddr__pureZdynlib_30(m, "PyDict_New");
	(*pl).PyDict_New = ((tyProc__NzboHqZVJcbdtVGYrOosXQ) (T290_));
	nimln_(294, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	{
		nimln_(203, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		if (!((*pl).PyDict_New == 0)) goto LA293_;
		nimln_(204, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		symNotLoadedErr__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_336("PyDict_New");
	}
	LA293_: ;
	nimln_(199, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	T295_ = (void*)0;
	T295_ = symAddr__pureZdynlib_30(m, "PyDict_Size");
	(*pl).PyDict_Size = ((tyProc__YRQqZC12s3573tRGP8MV3g) (T295_));
	nimln_(295, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	{
		nimln_(203, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		if (!((*pl).PyDict_Size == 0)) goto LA298_;
		nimln_(204, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		symNotLoadedErr__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_336("PyDict_Size");
	}
	LA298_: ;
	nimln_(199, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	T300_ = (void*)0;
	T300_ = symAddr__pureZdynlib_30(m, "PyDict_GetItemString");
	(*pl).PyDict_GetItemString = ((tyProc__YezmFzxOOyM9cb11Eoq1Elg) (T300_));
	nimln_(296, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	{
		nimln_(203, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		if (!((*pl).PyDict_GetItemString == 0)) goto LA303_;
		nimln_(204, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		symNotLoadedErr__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_336("PyDict_GetItemString");
	}
	LA303_: ;
	nimln_(199, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	T305_ = (void*)0;
	T305_ = symAddr__pureZdynlib_30(m, "PyDict_SetItemString");
	(*pl).PyDict_SetItemString = ((tyProc__T08W9bgbY4bOv2q64h6irpw) (T305_));
	nimln_(297, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	{
		nimln_(203, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		if (!((*pl).PyDict_SetItemString == 0)) goto LA308_;
		nimln_(204, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		symNotLoadedErr__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_336("PyDict_SetItemString");
	}
	LA308_: ;
	nimln_(199, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	T310_ = (void*)0;
	T310_ = symAddr__pureZdynlib_30(m, "PyDict_GetItem");
	(*pl).PyDict_GetItem = ((tyProc__VQ1ysQk017myXMGb79cPTVw) (T310_));
	nimln_(298, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	{
		nimln_(203, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		if (!((*pl).PyDict_GetItem == 0)) goto LA313_;
		nimln_(204, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		symNotLoadedErr__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_336("PyDict_GetItem");
	}
	LA313_: ;
	nimln_(199, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	T315_ = (void*)0;
	T315_ = symAddr__pureZdynlib_30(m, "PyDict_SetItem");
	(*pl).PyDict_SetItem = ((tyProc__7LMjBc4zOHVIsNdulNv7QQ) (T315_));
	nimln_(299, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	{
		nimln_(203, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		if (!((*pl).PyDict_SetItem == 0)) goto LA318_;
		nimln_(204, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		symNotLoadedErr__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_336("PyDict_SetItem");
	}
	LA318_: ;
	nimln_(199, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	T320_ = (void*)0;
	T320_ = symAddr__pureZdynlib_30(m, "PyDict_Keys");
	(*pl).PyDict_Keys = ((tyProc__jvPpjMAkI9bwM1B9apOphnlA) (T320_));
	nimln_(300, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	{
		nimln_(203, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		if (!((*pl).PyDict_Keys == 0)) goto LA323_;
		nimln_(204, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		symNotLoadedErr__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_336("PyDict_Keys");
	}
	LA323_: ;
	nimln_(199, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	T325_ = (void*)0;
	T325_ = symAddr__pureZdynlib_30(m, "PyDict_Values");
	(*pl).PyDict_Values = ((tyProc__jvPpjMAkI9bwM1B9apOphnlA) (T325_));
	nimln_(301, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	{
		nimln_(203, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		if (!((*pl).PyDict_Values == 0)) goto LA328_;
		nimln_(204, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		symNotLoadedErr__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_336("PyDict_Values");
	}
	LA328_: ;
	nimln_(199, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	T330_ = (void*)0;
	T330_ = symAddr__pureZdynlib_30(m, "PyDict_Contains");
	(*pl).PyDict_Contains = ((tyProc__MTei9bsKjha0o1cISO9aLMDg) (T330_));
	nimln_(302, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	{
		nimln_(203, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		if (!((*pl).PyDict_Contains == 0)) goto LA333_;
		nimln_(204, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		symNotLoadedErr__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_336("PyDict_Contains");
	}
	LA333_: ;
	nimln_(199, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	T335_ = (void*)0;
	T335_ = symAddr__pureZdynlib_30(m, "PyErr_Clear");
	(*pl).PyErr_Clear = ((tyProc__ln4kdL5W9bbX4a1xl8nnVXQ) (T335_));
	nimln_(304, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	{
		nimln_(203, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		if (!((*pl).PyErr_Clear == 0)) goto LA338_;
		nimln_(204, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		symNotLoadedErr__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_336("PyErr_Clear");
	}
	LA338_: ;
	nimln_(199, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	T340_ = (void*)0;
	T340_ = symAddr__pureZdynlib_30(m, "PyErr_SetString");
	(*pl).PyErr_SetString = ((tyProc__WYY8i0I79agBofnUcEGCfig) (T340_));
	nimln_(305, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	{
		nimln_(203, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		if (!((*pl).PyErr_SetString == 0)) goto LA343_;
		nimln_(204, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		symNotLoadedErr__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_336("PyErr_SetString");
	}
	LA343_: ;
	nimln_(199, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	T345_ = (void*)0;
	T345_ = symAddr__pureZdynlib_30(m, "PyErr_Occurred");
	(*pl).PyErr_Occurred = ((tyProc__NzboHqZVJcbdtVGYrOosXQ) (T345_));
	nimln_(306, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	{
		nimln_(203, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		if (!((*pl).PyErr_Occurred == 0)) goto LA348_;
		nimln_(204, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		symNotLoadedErr__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_336("PyErr_Occurred");
	}
	LA348_: ;
	nimln_(199, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	T350_ = (void*)0;
	T350_ = symAddr__pureZdynlib_30(m, "PyExc_TypeError");
	(*pl).PyExc_TypeError = ((void*) (T350_));
	nimln_(210, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	{
		nimln_(203, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		if (!((*pl).PyExc_TypeError == 0)) goto LA353_;
		nimln_(204, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		symNotLoadedErr__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_336("PyExc_TypeError");
	}
	LA353_: ;
	nimln_(211, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	(*pl).PyExc_TypeError = (*((void**) ((*pl).PyExc_TypeError)));
	nimln_(199, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	T355_ = (void*)0;
	T355_ = symAddr__pureZdynlib_30(m, "PyCapsule_New");
	(*pl).PyCapsule_New = ((tyProc__jcEovQ2rZUNUsYxohT50Ug) (T355_));
	nimln_(310, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	{
		nimln_(203, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		if (!((*pl).PyCapsule_New == 0)) goto LA358_;
		nimln_(204, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		symNotLoadedErr__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_336("PyCapsule_New");
	}
	LA358_: ;
	nimln_(199, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	T360_ = (void*)0;
	T360_ = symAddr__pureZdynlib_30(m, "PyCapsule_GetPointer");
	(*pl).PyCapsule_GetPointer = ((tyProc__YezmFzxOOyM9cb11Eoq1Elg) (T360_));
	nimln_(311, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	{
		nimln_(203, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		if (!((*pl).PyCapsule_GetPointer == 0)) goto LA363_;
		nimln_(204, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		symNotLoadedErr__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_336("PyCapsule_GetPointer");
	}
	LA363_: ;
	nimln_(199, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	T365_ = (void*)0;
	T365_ = symAddr__pureZdynlib_30(m, "PyImport_ImportModule");
	(*pl).PyImport_ImportModule = ((tyProc__YDKrw1adv61oVQkQhbYyaA) (T365_));
	nimln_(313, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	{
		nimln_(203, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		if (!((*pl).PyImport_ImportModule == 0)) goto LA368_;
		nimln_(204, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		symNotLoadedErr__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_336("PyImport_ImportModule");
	}
	LA368_: ;
	nimln_(199, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	T370_ = (void*)0;
	T370_ = symAddr__pureZdynlib_30(m, "PyEval_GetBuiltins");
	(*pl).PyEval_GetBuiltins = ((tyProc__NzboHqZVJcbdtVGYrOosXQ) (T370_));
	nimln_(314, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	{
		nimln_(203, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		if (!((*pl).PyEval_GetBuiltins == 0)) goto LA373_;
		nimln_(204, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		symNotLoadedErr__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_336("PyEval_GetBuiltins");
	}
	LA373_: ;
	nimln_(199, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	T375_ = (void*)0;
	T375_ = symAddr__pureZdynlib_30(m, "PyEval_GetGlobals");
	(*pl).PyEval_GetGlobals = ((tyProc__NzboHqZVJcbdtVGYrOosXQ) (T375_));
	nimln_(315, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	{
		nimln_(203, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		if (!((*pl).PyEval_GetGlobals == 0)) goto LA378_;
		nimln_(204, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		symNotLoadedErr__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_336("PyEval_GetGlobals");
	}
	LA378_: ;
	nimln_(199, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	T380_ = (void*)0;
	T380_ = symAddr__pureZdynlib_30(m, "PyEval_GetLocals");
	(*pl).PyEval_GetLocals = ((tyProc__NzboHqZVJcbdtVGYrOosXQ) (T380_));
	nimln_(316, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	{
		nimln_(203, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		if (!((*pl).PyEval_GetLocals == 0)) goto LA383_;
		nimln_(204, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		symNotLoadedErr__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_336("PyEval_GetLocals");
	}
	LA383_: ;
	nimln_(199, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	T385_ = (void*)0;
	T385_ = symAddr__pureZdynlib_30(m, "PyCFunction_NewEx");
	(*pl).PyCFunction_NewEx = ((tyProc__9b2qzlf3LCKK0JvThQT1atg) (T385_));
	nimln_(318, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	{
		nimln_(203, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		if (!((*pl).PyCFunction_NewEx == 0)) goto LA388_;
		nimln_(204, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		symNotLoadedErr__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_336("PyCFunction_NewEx");
	}
	LA388_: ;
	nimln_(199, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	T390_ = (void*)0;
	T390_ = symAddr__pureZdynlib_30(m, "PyErr_Print");
	(*pl).PyErr_Print = ((tyProc__ln4kdL5W9bbX4a1xl8nnVXQ) (T390_));
	nimln_(321, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	{
		nimln_(203, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		if (!((*pl).PyErr_Print == 0)) goto LA393_;
		nimln_(204, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		symNotLoadedErr__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_336("PyErr_Print");
	}
	LA393_: ;
	nimln_(199, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	T395_ = (void*)0;
	T395_ = symAddr__pureZdynlib_30(m, "PyErr_Fetch");
	(*pl).PyErr_Fetch = ((tyProc__U0oVFt576Ze44Q9a3eZc5wg) (T395_));
	nimln_(323, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	{
		nimln_(203, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		if (!((*pl).PyErr_Fetch == 0)) goto LA398_;
		nimln_(204, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		symNotLoadedErr__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_336("PyErr_Fetch");
	}
	LA398_: ;
	nimln_(199, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	T400_ = (void*)0;
	T400_ = symAddr__pureZdynlib_30(m, "PyErr_NormalizeException");
	(*pl).PyErr_NormalizeException = ((tyProc__U0oVFt576Ze44Q9a3eZc5wg) (T400_));
	nimln_(324, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	{
		nimln_(203, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		if (!((*pl).PyErr_NormalizeException == 0)) goto LA403_;
		nimln_(204, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		symNotLoadedErr__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_336("PyErr_NormalizeException");
	}
	LA403_: ;
	nimln_(199, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	T405_ = (void*)0;
	T405_ = symAddr__pureZdynlib_30(m, "PyErr_GivenExceptionMatches");
	(*pl).PyErr_GivenExceptionMatches = ((tyProc__MTei9bsKjha0o1cISO9aLMDg) (T405_));
	nimln_(325, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	{
		nimln_(203, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		if (!((*pl).PyErr_GivenExceptionMatches == 0)) goto LA408_;
		nimln_(204, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		symNotLoadedErr__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_336("PyErr_GivenExceptionMatches");
	}
	LA408_: ;
	nimln_(199, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	T410_ = (void*)0;
	T410_ = symAddr__pureZdynlib_30(m, "PyErr_NewException");
	(*pl).PyErr_NewException = ((tyProc__BZ6N5NNdHcK05FTDxQbEWw) (T410_));
	nimln_(327, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	{
		nimln_(203, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		if (!((*pl).PyErr_NewException == 0)) goto LA413_;
		nimln_(204, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		symNotLoadedErr__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_336("PyErr_NewException");
	}
	LA413_: ;
	nimln_(199, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	T415_ = (void*)0;
	T415_ = symAddr__pureZdynlib_30(m, "PyExc_ArithmeticError");
	(*pl).PyExc_ArithmeticError = ((void*) (T415_));
	nimln_(210, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	{
		nimln_(203, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		if (!((*pl).PyExc_ArithmeticError == 0)) goto LA418_;
		nimln_(204, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		symNotLoadedErr__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_336("PyExc_ArithmeticError");
	}
	LA418_: ;
	nimln_(211, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	(*pl).PyExc_ArithmeticError = (*((void**) ((*pl).PyExc_ArithmeticError)));
	nimln_(199, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	T420_ = (void*)0;
	T420_ = symAddr__pureZdynlib_30(m, "PyExc_FloatingPointError");
	(*pl).PyExc_FloatingPointError = ((void*) (T420_));
	nimln_(210, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	{
		nimln_(203, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		if (!((*pl).PyExc_FloatingPointError == 0)) goto LA423_;
		nimln_(204, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		symNotLoadedErr__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_336("PyExc_FloatingPointError");
	}
	LA423_: ;
	nimln_(211, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	(*pl).PyExc_FloatingPointError = (*((void**) ((*pl).PyExc_FloatingPointError)));
	nimln_(199, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	T425_ = (void*)0;
	T425_ = symAddr__pureZdynlib_30(m, "PyExc_OverflowError");
	(*pl).PyExc_OverflowError = ((void*) (T425_));
	nimln_(210, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	{
		nimln_(203, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		if (!((*pl).PyExc_OverflowError == 0)) goto LA428_;
		nimln_(204, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		symNotLoadedErr__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_336("PyExc_OverflowError");
	}
	LA428_: ;
	nimln_(211, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	(*pl).PyExc_OverflowError = (*((void**) ((*pl).PyExc_OverflowError)));
	nimln_(199, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	T430_ = (void*)0;
	T430_ = symAddr__pureZdynlib_30(m, "PyExc_ZeroDivisionError");
	(*pl).PyExc_ZeroDivisionError = ((void*) (T430_));
	nimln_(210, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	{
		nimln_(203, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		if (!((*pl).PyExc_ZeroDivisionError == 0)) goto LA433_;
		nimln_(204, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		symNotLoadedErr__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_336("PyExc_ZeroDivisionError");
	}
	LA433_: ;
	nimln_(211, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	(*pl).PyExc_ZeroDivisionError = (*((void**) ((*pl).PyExc_ZeroDivisionError)));
	nimln_(199, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	T435_ = (void*)0;
	T435_ = symAddr__pureZdynlib_30(m, "PyExc_AssertionError");
	(*pl).PyExc_AssertionError = ((void*) (T435_));
	nimln_(210, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	{
		nimln_(203, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		if (!((*pl).PyExc_AssertionError == 0)) goto LA438_;
		nimln_(204, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		symNotLoadedErr__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_336("PyExc_AssertionError");
	}
	LA438_: ;
	nimln_(211, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	(*pl).PyExc_AssertionError = (*((void**) ((*pl).PyExc_AssertionError)));
	nimln_(199, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	T440_ = (void*)0;
	T440_ = symAddr__pureZdynlib_30(m, "PyExc_OSError");
	(*pl).PyExc_OSError = ((void*) (T440_));
	nimln_(210, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	{
		nimln_(203, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		if (!((*pl).PyExc_OSError == 0)) goto LA443_;
		nimln_(204, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		symNotLoadedErr__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_336("PyExc_OSError");
	}
	LA443_: ;
	nimln_(211, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	(*pl).PyExc_OSError = (*((void**) ((*pl).PyExc_OSError)));
	nimln_(199, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	T445_ = (void*)0;
	T445_ = symAddr__pureZdynlib_30(m, "PyExc_IOError");
	(*pl).PyExc_IOError = ((void*) (T445_));
	nimln_(210, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	{
		nimln_(203, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		if (!((*pl).PyExc_IOError == 0)) goto LA448_;
		nimln_(204, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		symNotLoadedErr__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_336("PyExc_IOError");
	}
	LA448_: ;
	nimln_(211, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	(*pl).PyExc_IOError = (*((void**) ((*pl).PyExc_IOError)));
	nimln_(199, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	T450_ = (void*)0;
	T450_ = symAddr__pureZdynlib_30(m, "PyExc_ValueError");
	(*pl).PyExc_ValueError = ((void*) (T450_));
	nimln_(210, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	{
		nimln_(203, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		if (!((*pl).PyExc_ValueError == 0)) goto LA453_;
		nimln_(204, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		symNotLoadedErr__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_336("PyExc_ValueError");
	}
	LA453_: ;
	nimln_(211, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	(*pl).PyExc_ValueError = (*((void**) ((*pl).PyExc_ValueError)));
	nimln_(199, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	T455_ = (void*)0;
	T455_ = symAddr__pureZdynlib_30(m, "PyExc_EOFError");
	(*pl).PyExc_EOFError = ((void*) (T455_));
	nimln_(210, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	{
		nimln_(203, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		if (!((*pl).PyExc_EOFError == 0)) goto LA458_;
		nimln_(204, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		symNotLoadedErr__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_336("PyExc_EOFError");
	}
	LA458_: ;
	nimln_(211, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	(*pl).PyExc_EOFError = (*((void**) ((*pl).PyExc_EOFError)));
	nimln_(199, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	T460_ = (void*)0;
	T460_ = symAddr__pureZdynlib_30(m, "PyExc_MemoryError");
	(*pl).PyExc_MemoryError = ((void*) (T460_));
	nimln_(210, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	{
		nimln_(203, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		if (!((*pl).PyExc_MemoryError == 0)) goto LA463_;
		nimln_(204, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		symNotLoadedErr__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_336("PyExc_MemoryError");
	}
	LA463_: ;
	nimln_(211, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	(*pl).PyExc_MemoryError = (*((void**) ((*pl).PyExc_MemoryError)));
	nimln_(199, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	T465_ = (void*)0;
	T465_ = symAddr__pureZdynlib_30(m, "PyExc_IndexError");
	(*pl).PyExc_IndexError = ((void*) (T465_));
	nimln_(210, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	{
		nimln_(203, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		if (!((*pl).PyExc_IndexError == 0)) goto LA468_;
		nimln_(204, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		symNotLoadedErr__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_336("PyExc_IndexError");
	}
	LA468_: ;
	nimln_(211, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	(*pl).PyExc_IndexError = (*((void**) ((*pl).PyExc_IndexError)));
	nimln_(199, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	T470_ = (void*)0;
	T470_ = symAddr__pureZdynlib_30(m, "PyExc_KeyError");
	(*pl).PyExc_KeyError = ((void*) (T470_));
	nimln_(210, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	{
		nimln_(203, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		if (!((*pl).PyExc_KeyError == 0)) goto LA473_;
		nimln_(204, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		symNotLoadedErr__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_336("PyExc_KeyError");
	}
	LA473_: ;
	nimln_(211, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	(*pl).PyExc_KeyError = (*((void**) ((*pl).PyExc_KeyError)));
	nimln_(342, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	{
		if (!((*pl).pythonVersion.Field0 == ((NI) 3))) goto LA477_;
		nimln_(343, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		(*pl).PyDealloc = deallocPythonObj__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_629;
	}
	goto LA475_;
	LA477_: ;
	{
		nimln_(345, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
		(*pl).PyDealloc = deallocPythonObj__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_629;
	}
	LA475_: ;
	popFrame();
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, registerExportedModule__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_308)(NimStringDesc* name, void* initAddr2, void* initAddr3) {
	tyObject_ExportedModule__fxDBwb9c9c8NsdRe9bmg8Q9a2A T1_;
	NI T2_;
	NimStringDesc* T3_;
	nimfr_("registerExportedModule", "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	nimln_(145, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	nimZeroMem((void*)(&T1_), sizeof(tyObject_ExportedModule__fxDBwb9c9c8NsdRe9bmg8Q9a2A));
	nimZeroMem((void*)(&T1_), sizeof(tyObject_ExportedModule__fxDBwb9c9c8NsdRe9bmg8Q9a2A));
	T1_.name = copyString(name);
	T1_.initAddr2 = initAddr2;
	T1_.initAddr3 = initAddr3;
	asgnRef((void**) (&exportedModules__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_289), (tySequence__M73GJ9bOx1XdoIRnhIyhqTQ*) incrSeqV3((TGenericSeq*)(exportedModules__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_289), (&NTIseqLexportedmoduleT__M73GJ9bOx1XdoIRnhIyhqTQ_)));
	T2_ = exportedModules__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_289->Sup.len++;
	T3_ = NIM_NIL;
	T3_ = exportedModules__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_289->data[T2_].name; exportedModules__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_289->data[T2_].name = copyStringRC1(T1_.name);
	if (T3_) nimGCunrefNoCycle(T3_);
	exportedModules__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_289->data[T2_].initAddr2 = T1_.initAddr2;
	exportedModules__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_289->data[T2_].initAddr3 = T1_.initAddr3;
	popFrame();
}
N_LIB_PRIVATE N_NIMCALL(void, nimpy_py_libInit000)(void) {
{
	TFrame FR_; FR_.len = 0;

	nimRegisterGlobalMarker(TM__XnAUe69cYg8yQhnmiRJUnHw_3);

}/* preInitProc end */
{
	nimfr_("py_lib", "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	nimln_(142, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy/py_lib.nim");
	if (exportedModules__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_289) { nimGCunrefRC1(exportedModules__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_289); exportedModules__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_289 = NIM_NIL; }
	popFrame();
}
}

N_LIB_PRIVATE N_NIMCALL(void, nimpy_py_libDatInit000)(void) {
static TNimNode* TM__XnAUe69cYg8yQhnmiRJUnHw_2_3[3];
static TNimNode TM__XnAUe69cYg8yQhnmiRJUnHw_0[4];
NTIexportedmodule__fxDBwb9c9c8NsdRe9bmg8Q9a2A_.size = sizeof(tyObject_ExportedModule__fxDBwb9c9c8NsdRe9bmg8Q9a2A);
NTIexportedmodule__fxDBwb9c9c8NsdRe9bmg8Q9a2A_.align = NIM_ALIGNOF(tyObject_ExportedModule__fxDBwb9c9c8NsdRe9bmg8Q9a2A);
NTIexportedmodule__fxDBwb9c9c8NsdRe9bmg8Q9a2A_.kind = 18;
NTIexportedmodule__fxDBwb9c9c8NsdRe9bmg8Q9a2A_.base = 0;
TM__XnAUe69cYg8yQhnmiRJUnHw_2_3[0] = &TM__XnAUe69cYg8yQhnmiRJUnHw_0[1];
TM__XnAUe69cYg8yQhnmiRJUnHw_0[1].kind = 1;
TM__XnAUe69cYg8yQhnmiRJUnHw_0[1].offset = offsetof(tyObject_ExportedModule__fxDBwb9c9c8NsdRe9bmg8Q9a2A, name);
TM__XnAUe69cYg8yQhnmiRJUnHw_0[1].typ = (&NTIstring__77mFvmsOLKik79ci2hXkHEg_);
TM__XnAUe69cYg8yQhnmiRJUnHw_0[1].name = "name";
TM__XnAUe69cYg8yQhnmiRJUnHw_2_3[1] = &TM__XnAUe69cYg8yQhnmiRJUnHw_0[2];
TM__XnAUe69cYg8yQhnmiRJUnHw_0[2].kind = 1;
TM__XnAUe69cYg8yQhnmiRJUnHw_0[2].offset = offsetof(tyObject_ExportedModule__fxDBwb9c9c8NsdRe9bmg8Q9a2A, initAddr2);
TM__XnAUe69cYg8yQhnmiRJUnHw_0[2].typ = (&NTIpointer__vr5DoT1jILTGdRlYv1OYpw_);
TM__XnAUe69cYg8yQhnmiRJUnHw_0[2].name = "initAddr2";
TM__XnAUe69cYg8yQhnmiRJUnHw_2_3[2] = &TM__XnAUe69cYg8yQhnmiRJUnHw_0[3];
TM__XnAUe69cYg8yQhnmiRJUnHw_0[3].kind = 1;
TM__XnAUe69cYg8yQhnmiRJUnHw_0[3].offset = offsetof(tyObject_ExportedModule__fxDBwb9c9c8NsdRe9bmg8Q9a2A, initAddr3);
TM__XnAUe69cYg8yQhnmiRJUnHw_0[3].typ = (&NTIpointer__vr5DoT1jILTGdRlYv1OYpw_);
TM__XnAUe69cYg8yQhnmiRJUnHw_0[3].name = "initAddr3";
TM__XnAUe69cYg8yQhnmiRJUnHw_0[0].len = 3; TM__XnAUe69cYg8yQhnmiRJUnHw_0[0].kind = 2; TM__XnAUe69cYg8yQhnmiRJUnHw_0[0].sons = &TM__XnAUe69cYg8yQhnmiRJUnHw_2_3[0];
NTIexportedmodule__fxDBwb9c9c8NsdRe9bmg8Q9a2A_.node = &TM__XnAUe69cYg8yQhnmiRJUnHw_0[0];
NTIseqLexportedmoduleT__M73GJ9bOx1XdoIRnhIyhqTQ_.size = sizeof(tySequence__M73GJ9bOx1XdoIRnhIyhqTQ*);
NTIseqLexportedmoduleT__M73GJ9bOx1XdoIRnhIyhqTQ_.align = NIM_ALIGNOF(tySequence__M73GJ9bOx1XdoIRnhIyhqTQ*);
NTIseqLexportedmoduleT__M73GJ9bOx1XdoIRnhIyhqTQ_.kind = 24;
NTIseqLexportedmoduleT__M73GJ9bOx1XdoIRnhIyhqTQ_.base = (&NTIexportedmodule__fxDBwb9c9c8NsdRe9bmg8Q9a2A_);
NTIseqLexportedmoduleT__M73GJ9bOx1XdoIRnhIyhqTQ_.marker = Marker_tySequence__M73GJ9bOx1XdoIRnhIyhqTQ;
if (!((TM__XnAUe69cYg8yQhnmiRJUnHw_8 = nimLoadLibrary(((NimStringDesc*) &TM__XnAUe69cYg8yQhnmiRJUnHw_10)))
)) nimLoadLibraryError(((NimStringDesc*) &TM__XnAUe69cYg8yQhnmiRJUnHw_11));
	Dl_1560282111_ = (tyProc__Ph37G33p2ec6K0xFeDk1cQ) nimGetProcAddr(TM__XnAUe69cYg8yQhnmiRJUnHw_8, "K32EnumProcessModules");
}

